# coding: utf-8

"""
    communications-sms

    These APIs ensures an easy integration process of SMS management for developers to send, read, and track SMS histories within applications.  # noqa: E501

    OpenAPI spec version: 1.0.0
    
    Generated by: phenom
"""

import pprint
import re  # noqa: F401

import six

class SMSHistoryData(object):
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'created_date': 'int',
        'updated_date': 'int',
        'no_of_messages': 'int',
        'target': 'str',
        'user_id': 'str',
        'recruiter_user_id': 'str',
        'candidate_phone': 'str',
        'candidate_standard_phone': 'str',
        'recruiter_phone': 'str',
        'message': 'str',
        'is_read': 'bool',
        'parent': 'str',
        'time_stamp': 'int'
    }

    attribute_map = {
        'created_date': 'createdDate',
        'updated_date': 'updatedDate',
        'no_of_messages': 'noOfMessages',
        'target': 'target',
        'user_id': 'userId',
        'recruiter_user_id': 'recruiterUserId',
        'candidate_phone': 'candidatePhone',
        'candidate_standard_phone': 'candidateStandardPhone',
        'recruiter_phone': 'recruiterPhone',
        'message': 'message',
        'is_read': 'isRead',
        'parent': 'parent',
        'time_stamp': 'timeStamp'
    }

    def __init__(self, created_date=None, updated_date=None, no_of_messages=None, target=None, user_id=None, recruiter_user_id=None, candidate_phone=None, candidate_standard_phone=None, recruiter_phone=None, message=None, is_read=None, parent=None, time_stamp=None):  # noqa: E501
        """SMSHistoryData - a model defined in Swagger"""  # noqa: E501
        self._created_date = None
        self._updated_date = None
        self._no_of_messages = None
        self._target = None
        self._user_id = None
        self._recruiter_user_id = None
        self._candidate_phone = None
        self._candidate_standard_phone = None
        self._recruiter_phone = None
        self._message = None
        self._is_read = None
        self._parent = None
        self._time_stamp = None
        self.discriminator = None
        self.created_date = created_date
        self.updated_date = updated_date
        self.no_of_messages = no_of_messages
        self.target = target
        self.user_id = user_id
        self.recruiter_user_id = recruiter_user_id
        self.candidate_phone = candidate_phone
        self.candidate_standard_phone = candidate_standard_phone
        self.recruiter_phone = recruiter_phone
        self.message = message
        self.is_read = is_read
        self.parent = parent
        self.time_stamp = time_stamp

    @property
    def created_date(self):
        """Gets the created_date of this SMSHistoryData.  # noqa: E501

        Timestamp when the SMS history entry was created.  # noqa: E501

        :return: The created_date of this SMSHistoryData.  # noqa: E501
        :rtype: int
        """
        return self._created_date

    @created_date.setter
    def created_date(self, created_date):
        """Sets the created_date of this SMSHistoryData.

        Timestamp when the SMS history entry was created.  # noqa: E501

        :param created_date: The created_date of this SMSHistoryData.  # noqa: E501
        :type: int
        """
        if created_date is None:
            raise ValueError("Invalid value for `created_date`, must not be `None`")  # noqa: E501

        self._created_date = created_date

    @property
    def updated_date(self):
        """Gets the updated_date of this SMSHistoryData.  # noqa: E501

        Timestamp when the SMS history entry was last updated.  # noqa: E501

        :return: The updated_date of this SMSHistoryData.  # noqa: E501
        :rtype: int
        """
        return self._updated_date

    @updated_date.setter
    def updated_date(self, updated_date):
        """Sets the updated_date of this SMSHistoryData.

        Timestamp when the SMS history entry was last updated.  # noqa: E501

        :param updated_date: The updated_date of this SMSHistoryData.  # noqa: E501
        :type: int
        """
        if updated_date is None:
            raise ValueError("Invalid value for `updated_date`, must not be `None`")  # noqa: E501

        self._updated_date = updated_date

    @property
    def no_of_messages(self):
        """Gets the no_of_messages of this SMSHistoryData.  # noqa: E501

        Number of messages in the SMS history .  # noqa: E501

        :return: The no_of_messages of this SMSHistoryData.  # noqa: E501
        :rtype: int
        """
        return self._no_of_messages

    @no_of_messages.setter
    def no_of_messages(self, no_of_messages):
        """Sets the no_of_messages of this SMSHistoryData.

        Number of messages in the SMS history .  # noqa: E501

        :param no_of_messages: The no_of_messages of this SMSHistoryData.  # noqa: E501
        :type: int
        """
        if no_of_messages is None:
            raise ValueError("Invalid value for `no_of_messages`, must not be `None`")  # noqa: E501

        self._no_of_messages = no_of_messages

    @property
    def target(self):
        """Gets the target of this SMSHistoryData.  # noqa: E501

        The target of the SMS history.  # noqa: E501

        :return: The target of this SMSHistoryData.  # noqa: E501
        :rtype: str
        """
        return self._target

    @target.setter
    def target(self, target):
        """Sets the target of this SMSHistoryData.

        The target of the SMS history.  # noqa: E501

        :param target: The target of this SMSHistoryData.  # noqa: E501
        :type: str
        """
        if target is None:
            raise ValueError("Invalid value for `target`, must not be `None`")  # noqa: E501

        self._target = target

    @property
    def user_id(self):
        """Gets the user_id of this SMSHistoryData.  # noqa: E501

        User ID associated with the SMS history .  # noqa: E501

        :return: The user_id of this SMSHistoryData.  # noqa: E501
        :rtype: str
        """
        return self._user_id

    @user_id.setter
    def user_id(self, user_id):
        """Sets the user_id of this SMSHistoryData.

        User ID associated with the SMS history .  # noqa: E501

        :param user_id: The user_id of this SMSHistoryData.  # noqa: E501
        :type: str
        """
        if user_id is None:
            raise ValueError("Invalid value for `user_id`, must not be `None`")  # noqa: E501

        self._user_id = user_id

    @property
    def recruiter_user_id(self):
        """Gets the recruiter_user_id of this SMSHistoryData.  # noqa: E501

        Recruiter user ID associated with the SMS history .  # noqa: E501

        :return: The recruiter_user_id of this SMSHistoryData.  # noqa: E501
        :rtype: str
        """
        return self._recruiter_user_id

    @recruiter_user_id.setter
    def recruiter_user_id(self, recruiter_user_id):
        """Sets the recruiter_user_id of this SMSHistoryData.

        Recruiter user ID associated with the SMS history .  # noqa: E501

        :param recruiter_user_id: The recruiter_user_id of this SMSHistoryData.  # noqa: E501
        :type: str
        """
        if recruiter_user_id is None:
            raise ValueError("Invalid value for `recruiter_user_id`, must not be `None`")  # noqa: E501

        self._recruiter_user_id = recruiter_user_id

    @property
    def candidate_phone(self):
        """Gets the candidate_phone of this SMSHistoryData.  # noqa: E501

        Phone number of the candidate associated with the SMS history .  # noqa: E501

        :return: The candidate_phone of this SMSHistoryData.  # noqa: E501
        :rtype: str
        """
        return self._candidate_phone

    @candidate_phone.setter
    def candidate_phone(self, candidate_phone):
        """Sets the candidate_phone of this SMSHistoryData.

        Phone number of the candidate associated with the SMS history .  # noqa: E501

        :param candidate_phone: The candidate_phone of this SMSHistoryData.  # noqa: E501
        :type: str
        """
        if candidate_phone is None:
            raise ValueError("Invalid value for `candidate_phone`, must not be `None`")  # noqa: E501

        self._candidate_phone = candidate_phone

    @property
    def candidate_standard_phone(self):
        """Gets the candidate_standard_phone of this SMSHistoryData.  # noqa: E501

        Standardized phone number of the candidate.  # noqa: E501

        :return: The candidate_standard_phone of this SMSHistoryData.  # noqa: E501
        :rtype: str
        """
        return self._candidate_standard_phone

    @candidate_standard_phone.setter
    def candidate_standard_phone(self, candidate_standard_phone):
        """Sets the candidate_standard_phone of this SMSHistoryData.

        Standardized phone number of the candidate.  # noqa: E501

        :param candidate_standard_phone: The candidate_standard_phone of this SMSHistoryData.  # noqa: E501
        :type: str
        """
        if candidate_standard_phone is None:
            raise ValueError("Invalid value for `candidate_standard_phone`, must not be `None`")  # noqa: E501

        self._candidate_standard_phone = candidate_standard_phone

    @property
    def recruiter_phone(self):
        """Gets the recruiter_phone of this SMSHistoryData.  # noqa: E501

        Phone number of the recruiter associated with the SMS history.  # noqa: E501

        :return: The recruiter_phone of this SMSHistoryData.  # noqa: E501
        :rtype: str
        """
        return self._recruiter_phone

    @recruiter_phone.setter
    def recruiter_phone(self, recruiter_phone):
        """Sets the recruiter_phone of this SMSHistoryData.

        Phone number of the recruiter associated with the SMS history.  # noqa: E501

        :param recruiter_phone: The recruiter_phone of this SMSHistoryData.  # noqa: E501
        :type: str
        """
        if recruiter_phone is None:
            raise ValueError("Invalid value for `recruiter_phone`, must not be `None`")  # noqa: E501

        self._recruiter_phone = recruiter_phone

    @property
    def message(self):
        """Gets the message of this SMSHistoryData.  # noqa: E501

        Content of the SMS message in the history.  # noqa: E501

        :return: The message of this SMSHistoryData.  # noqa: E501
        :rtype: str
        """
        return self._message

    @message.setter
    def message(self, message):
        """Sets the message of this SMSHistoryData.

        Content of the SMS message in the history.  # noqa: E501

        :param message: The message of this SMSHistoryData.  # noqa: E501
        :type: str
        """
        if message is None:
            raise ValueError("Invalid value for `message`, must not be `None`")  # noqa: E501

        self._message = message

    @property
    def is_read(self):
        """Gets the is_read of this SMSHistoryData.  # noqa: E501

        Indicates whether the SMS history  has been read.  # noqa: E501

        :return: The is_read of this SMSHistoryData.  # noqa: E501
        :rtype: bool
        """
        return self._is_read

    @is_read.setter
    def is_read(self, is_read):
        """Sets the is_read of this SMSHistoryData.

        Indicates whether the SMS history  has been read.  # noqa: E501

        :param is_read: The is_read of this SMSHistoryData.  # noqa: E501
        :type: bool
        """
        if is_read is None:
            raise ValueError("Invalid value for `is_read`, must not be `None`")  # noqa: E501

        self._is_read = is_read

    @property
    def parent(self):
        """Gets the parent of this SMSHistoryData.  # noqa: E501

        Parent identifier associated with the SMS history.  # noqa: E501

        :return: The parent of this SMSHistoryData.  # noqa: E501
        :rtype: str
        """
        return self._parent

    @parent.setter
    def parent(self, parent):
        """Sets the parent of this SMSHistoryData.

        Parent identifier associated with the SMS history.  # noqa: E501

        :param parent: The parent of this SMSHistoryData.  # noqa: E501
        :type: str
        """
        if parent is None:
            raise ValueError("Invalid value for `parent`, must not be `None`")  # noqa: E501

        self._parent = parent

    @property
    def time_stamp(self):
        """Gets the time_stamp of this SMSHistoryData.  # noqa: E501

        Timestamp associated with the SMS history.  # noqa: E501

        :return: The time_stamp of this SMSHistoryData.  # noqa: E501
        :rtype: int
        """
        return self._time_stamp

    @time_stamp.setter
    def time_stamp(self, time_stamp):
        """Sets the time_stamp of this SMSHistoryData.

        Timestamp associated with the SMS history.  # noqa: E501

        :param time_stamp: The time_stamp of this SMSHistoryData.  # noqa: E501
        :type: int
        """
        if time_stamp is None:
            raise ValueError("Invalid value for `time_stamp`, must not be `None`")  # noqa: E501

        self._time_stamp = time_stamp

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(SMSHistoryData, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, SMSHistoryData):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    projects-api

    These APIs allows you to create workflow statuses, which are then assigned to workflows. These workflows, containing multiple statuses, are subsequently linked to projects. Additionally, candidates are associated with projects, defining the path they are meant to follow within the established workflows.  # noqa: E501

    OpenAPI spec version: 1.0.0
    
    Generated by: phenom
"""

import pprint
import re  # noqa: F401

import six

class GetProjectsResponseMatchingCriteria(object):
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'must_have_skills': 'list[object]',
        'good_to_have_skills': 'list[object]',
        'location_list': 'list[object]',
        'years_of_experience': 'GetProjectsResponseMatchingCriteriaYearsOfExperience',
        'distance': 'GetProjectsResponseMatchingCriteriaDistance',
        'similar_job_title': 'str',
        'ideal_candidate': 'object'
    }

    attribute_map = {
        'must_have_skills': 'mustHaveSkills',
        'good_to_have_skills': 'goodToHaveSkills',
        'location_list': 'locationList',
        'years_of_experience': 'yearsOfExperience',
        'distance': 'distance',
        'similar_job_title': 'similarJobTitle',
        'ideal_candidate': 'idealCandidate'
    }

    def __init__(self, must_have_skills=None, good_to_have_skills=None, location_list=None, years_of_experience=None, distance=None, similar_job_title=None, ideal_candidate=None):  # noqa: E501
        """GetProjectsResponseMatchingCriteria - a model defined in Swagger"""  # noqa: E501
        self._must_have_skills = None
        self._good_to_have_skills = None
        self._location_list = None
        self._years_of_experience = None
        self._distance = None
        self._similar_job_title = None
        self._ideal_candidate = None
        self.discriminator = None
        if must_have_skills is not None:
            self.must_have_skills = must_have_skills
        if good_to_have_skills is not None:
            self.good_to_have_skills = good_to_have_skills
        if location_list is not None:
            self.location_list = location_list
        if years_of_experience is not None:
            self.years_of_experience = years_of_experience
        if distance is not None:
            self.distance = distance
        if similar_job_title is not None:
            self.similar_job_title = similar_job_title
        if ideal_candidate is not None:
            self.ideal_candidate = ideal_candidate

    @property
    def must_have_skills(self):
        """Gets the must_have_skills of this GetProjectsResponseMatchingCriteria.  # noqa: E501

        An array containing details of must-have skills for the project.  # noqa: E501

        :return: The must_have_skills of this GetProjectsResponseMatchingCriteria.  # noqa: E501
        :rtype: list[object]
        """
        return self._must_have_skills

    @must_have_skills.setter
    def must_have_skills(self, must_have_skills):
        """Sets the must_have_skills of this GetProjectsResponseMatchingCriteria.

        An array containing details of must-have skills for the project.  # noqa: E501

        :param must_have_skills: The must_have_skills of this GetProjectsResponseMatchingCriteria.  # noqa: E501
        :type: list[object]
        """

        self._must_have_skills = must_have_skills

    @property
    def good_to_have_skills(self):
        """Gets the good_to_have_skills of this GetProjectsResponseMatchingCriteria.  # noqa: E501

        An array containing details of good-to-have skills for the project.  # noqa: E501

        :return: The good_to_have_skills of this GetProjectsResponseMatchingCriteria.  # noqa: E501
        :rtype: list[object]
        """
        return self._good_to_have_skills

    @good_to_have_skills.setter
    def good_to_have_skills(self, good_to_have_skills):
        """Sets the good_to_have_skills of this GetProjectsResponseMatchingCriteria.

        An array containing details of good-to-have skills for the project.  # noqa: E501

        :param good_to_have_skills: The good_to_have_skills of this GetProjectsResponseMatchingCriteria.  # noqa: E501
        :type: list[object]
        """

        self._good_to_have_skills = good_to_have_skills

    @property
    def location_list(self):
        """Gets the location_list of this GetProjectsResponseMatchingCriteria.  # noqa: E501

        An array containing details of locations for the project.  # noqa: E501

        :return: The location_list of this GetProjectsResponseMatchingCriteria.  # noqa: E501
        :rtype: list[object]
        """
        return self._location_list

    @location_list.setter
    def location_list(self, location_list):
        """Sets the location_list of this GetProjectsResponseMatchingCriteria.

        An array containing details of locations for the project.  # noqa: E501

        :param location_list: The location_list of this GetProjectsResponseMatchingCriteria.  # noqa: E501
        :type: list[object]
        """

        self._location_list = location_list

    @property
    def years_of_experience(self):
        """Gets the years_of_experience of this GetProjectsResponseMatchingCriteria.  # noqa: E501


        :return: The years_of_experience of this GetProjectsResponseMatchingCriteria.  # noqa: E501
        :rtype: GetProjectsResponseMatchingCriteriaYearsOfExperience
        """
        return self._years_of_experience

    @years_of_experience.setter
    def years_of_experience(self, years_of_experience):
        """Sets the years_of_experience of this GetProjectsResponseMatchingCriteria.


        :param years_of_experience: The years_of_experience of this GetProjectsResponseMatchingCriteria.  # noqa: E501
        :type: GetProjectsResponseMatchingCriteriaYearsOfExperience
        """

        self._years_of_experience = years_of_experience

    @property
    def distance(self):
        """Gets the distance of this GetProjectsResponseMatchingCriteria.  # noqa: E501


        :return: The distance of this GetProjectsResponseMatchingCriteria.  # noqa: E501
        :rtype: GetProjectsResponseMatchingCriteriaDistance
        """
        return self._distance

    @distance.setter
    def distance(self, distance):
        """Sets the distance of this GetProjectsResponseMatchingCriteria.


        :param distance: The distance of this GetProjectsResponseMatchingCriteria.  # noqa: E501
        :type: GetProjectsResponseMatchingCriteriaDistance
        """

        self._distance = distance

    @property
    def similar_job_title(self):
        """Gets the similar_job_title of this GetProjectsResponseMatchingCriteria.  # noqa: E501

        The similar job title for the project.  # noqa: E501

        :return: The similar_job_title of this GetProjectsResponseMatchingCriteria.  # noqa: E501
        :rtype: str
        """
        return self._similar_job_title

    @similar_job_title.setter
    def similar_job_title(self, similar_job_title):
        """Sets the similar_job_title of this GetProjectsResponseMatchingCriteria.

        The similar job title for the project.  # noqa: E501

        :param similar_job_title: The similar_job_title of this GetProjectsResponseMatchingCriteria.  # noqa: E501
        :type: str
        """

        self._similar_job_title = similar_job_title

    @property
    def ideal_candidate(self):
        """Gets the ideal_candidate of this GetProjectsResponseMatchingCriteria.  # noqa: E501

        Details of the ideal candidate for the project.  # noqa: E501

        :return: The ideal_candidate of this GetProjectsResponseMatchingCriteria.  # noqa: E501
        :rtype: object
        """
        return self._ideal_candidate

    @ideal_candidate.setter
    def ideal_candidate(self, ideal_candidate):
        """Sets the ideal_candidate of this GetProjectsResponseMatchingCriteria.

        Details of the ideal candidate for the project.  # noqa: E501

        :param ideal_candidate: The ideal_candidate of this GetProjectsResponseMatchingCriteria.  # noqa: E501
        :type: object
        """

        self._ideal_candidate = ideal_candidate

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(GetProjectsResponseMatchingCriteria, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, GetProjectsResponseMatchingCriteria):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

# flake8: noqa
"""
    resume-parser-api

    The Resume Parser extracts important information of a candidate such as candidate's name, contact information, email id, education, work experience, and skills, etc. from the resume using Deep learning models.  # noqa: E501

    OpenAPI spec version: 1.0.0
    
    Generated by: phenom
"""

from __future__ import absolute_import

# import models into model package
from phenom.api.resumeparser.models.error_response import ErrorResponse
from phenom.api.resumeparser.models.error_response_errors import ErrorResponseErrors
from phenom.api.resumeparser.models.resume_file_request import ResumeFileRequest
from phenom.api.resumeparser.models.resume_request import ResumeRequest
from phenom.api.resumeparser.models.resume_response import ResumeResponse
from phenom.api.resumeparser.models.resume_response_data import ResumeResponseData
from phenom.api.resumeparser.models.resume_response_data_resumedata import ResumeResponseDataResumedata
from phenom.api.resumeparser.models.resume_response_data_resumedata_educationhistory import ResumeResponseDataResumedataEducationhistory
from phenom.api.resumeparser.models.resume_response_data_resumedata_experiencesummary import ResumeResponseDataResumedataExperiencesummary
from phenom.api.resumeparser.models.resume_response_data_resumedata_internetaddress import ResumeResponseDataResumedataInternetaddress
from phenom.api.resumeparser.models.resume_response_data_resumedata_mobile import ResumeResponseDataResumedataMobile
from phenom.api.resumeparser.models.resume_response_data_resumedata_personname import ResumeResponseDataResumedataPersonname
from phenom.api.resumeparser.models.resume_response_data_resumedata_postaladdress import ResumeResponseDataResumedataPostaladdress
from phenom.api.resumeparser.models.resume_response_data_resumedata_skilltaxonomy import ResumeResponseDataResumedataSkilltaxonomy
from phenom.api.resumeparser.models.resume_response_data_resumedata_workhistory import ResumeResponseDataResumedataWorkhistory



# coding: utf-8

"""
    job-parser-api

    The process of extracting important information from the raw job description is called Job Parsing. This information can include things like job titles, required skills, required experience, job duties, and qualifications.  # noqa: E501

    OpenAPI spec version: 1.0.0
    
    Generated by: phenom
"""

import pprint
import re  # noqa: F401

import six

class ErrorResponseResponse(object):
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'title': 'str',
        'status': 'int',
        'details': 'str',
        'error': 'str',
        'timestamp': 'str'
    }

    attribute_map = {
        'title': 'title',
        'status': 'status',
        'details': 'details',
        'error': 'error',
        'timestamp': 'timestamp'
    }

    def __init__(self, title=None, status=None, details=None, error=None, timestamp=None):  # noqa: E501
        """ErrorResponseResponse - a model defined in Swagger"""  # noqa: E501
        self._title = None
        self._status = None
        self._details = None
        self._error = None
        self._timestamp = None
        self.discriminator = None
        if title is not None:
            self.title = title
        if status is not None:
            self.status = status
        if details is not None:
            self.details = details
        if error is not None:
            self.error = error
        if timestamp is not None:
            self.timestamp = timestamp

    @property
    def title(self):
        """Gets the title of this ErrorResponseResponse.  # noqa: E501

        Title.  # noqa: E501

        :return: The title of this ErrorResponseResponse.  # noqa: E501
        :rtype: str
        """
        return self._title

    @title.setter
    def title(self, title):
        """Sets the title of this ErrorResponseResponse.

        Title.  # noqa: E501

        :param title: The title of this ErrorResponseResponse.  # noqa: E501
        :type: str
        """

        self._title = title

    @property
    def status(self):
        """Gets the status of this ErrorResponseResponse.  # noqa: E501

        Status.  # noqa: E501

        :return: The status of this ErrorResponseResponse.  # noqa: E501
        :rtype: int
        """
        return self._status

    @status.setter
    def status(self, status):
        """Sets the status of this ErrorResponseResponse.

        Status.  # noqa: E501

        :param status: The status of this ErrorResponseResponse.  # noqa: E501
        :type: int
        """

        self._status = status

    @property
    def details(self):
        """Gets the details of this ErrorResponseResponse.  # noqa: E501

        Error details.  # noqa: E501

        :return: The details of this ErrorResponseResponse.  # noqa: E501
        :rtype: str
        """
        return self._details

    @details.setter
    def details(self, details):
        """Sets the details of this ErrorResponseResponse.

        Error details.  # noqa: E501

        :param details: The details of this ErrorResponseResponse.  # noqa: E501
        :type: str
        """

        self._details = details

    @property
    def error(self):
        """Gets the error of this ErrorResponseResponse.  # noqa: E501

        Error message.  # noqa: E501

        :return: The error of this ErrorResponseResponse.  # noqa: E501
        :rtype: str
        """
        return self._error

    @error.setter
    def error(self, error):
        """Sets the error of this ErrorResponseResponse.

        Error message.  # noqa: E501

        :param error: The error of this ErrorResponseResponse.  # noqa: E501
        :type: str
        """

        self._error = error

    @property
    def timestamp(self):
        """Gets the timestamp of this ErrorResponseResponse.  # noqa: E501

        Time stamp.  # noqa: E501

        :return: The timestamp of this ErrorResponseResponse.  # noqa: E501
        :rtype: str
        """
        return self._timestamp

    @timestamp.setter
    def timestamp(self, timestamp):
        """Sets the timestamp of this ErrorResponseResponse.

        Time stamp.  # noqa: E501

        :param timestamp: The timestamp of this ErrorResponseResponse.  # noqa: E501
        :type: str
        """

        self._timestamp = timestamp

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(ErrorResponseResponse, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ErrorResponseResponse):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

# flake8: noqa
"""
    campaigns-sms

    These APIs ensures an easy integration process of SMS management for developers to send, read, and track SMS campaigns within applications.  # noqa: E501

    OpenAPI spec version: 1.0.0
    
    Generated by: phenom
"""

from __future__ import absolute_import

# import models into model package
from phenom.api.campaignssms.models.api_error import ApiError
from phenom.api.campaignssms.models.api_link import ApiLink
from phenom.api.campaignssms.models.bad_request import BadRequest
from phenom.api.campaignssms.models.internal_server_error import InternalServerError
from phenom.api.campaignssms.models.sms_activity import SMSActivity
from phenom.api.campaignssms.models.sms_activity_pagination import SMSActivityPagination
from phenom.api.campaignssms.models.sms_campaign_history import SMSCampaignHistory
from phenom.api.campaignssms.models.sms_campaign_history_data import SMSCampaignHistoryData
from phenom.api.campaignssms.models.sms_campaign_history_pagination import SMSCampaignHistoryPagination
from phenom.api.campaignssms.models.sms_campaign_opt_in import SMSCampaignOptIn
from phenom.api.campaignssms.models.sms_campaign_opt_in_details import SMSCampaignOptInDetails
from phenom.api.campaignssms.models.sms_campaign_opt_in_history import SMSCampaignOptInHistory
from phenom.api.campaignssms.models.sms_campaign_opt_in_history_details import SMSCampaignOptInHistoryDetails
from phenom.api.campaignssms.models.sms_campaign_opt_in_history_details_content import SMSCampaignOptInHistoryDetailsContent
from phenom.api.campaignssms.models.sms_campaign_opt_in_history_details_pageable import SMSCampaignOptInHistoryDetailsPageable
from phenom.api.campaignssms.models.sms_campaign_opt_in_history_details_pageable_sort import SMSCampaignOptInHistoryDetailsPageableSort
from phenom.api.campaignssms.models.sms_campaign_opt_in_history_details_sort import SMSCampaignOptInHistoryDetailsSort
from phenom.api.campaignssms.models.sms_campaign_opt_in_request import SMSCampaignOptInRequest
from phenom.api.campaignssms.models.sms_campaign_opt_in_response import SMSCampaignOptInResponse
from phenom.api.campaignssms.models.sms_campaign_opt_in_response_details import SMSCampaignOptInResponseDetails
from phenom.api.campaignssms.models.send_sms import SendSMS
from phenom.api.campaignssms.models.send_sms_campaign_request import SendSMSCampaignRequest
from phenom.api.campaignssms.models.send_sms_data import SendSMSData
from phenom.api.campaignssms.models.send_sms_request import SendSMSRequest
from phenom.api.campaignssms.models.unauthorized_request import UnauthorizedRequest



# coding: utf-8

"""
    resume-parser-api

    The Resume Parser extracts important information of a candidate such as candidate's name, contact information, email id, education, work experience, and skills, etc. from the resume using Deep learning models.  # noqa: E501

    OpenAPI spec version: 1.0.0
    
    Generated by: phenom
"""

import pprint
import re  # noqa: F401

import six

class ErrorResponseErrors(object):
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'error_api': 'str',
        'error_code': 'str',
        'time_stamp': 'str',
        'message': 'str',
        'message_key': 'str'
    }

    attribute_map = {
        'error_api': 'errorAPI',
        'error_code': 'errorCode',
        'time_stamp': 'timeStamp',
        'message': 'message',
        'message_key': 'messageKey'
    }

    def __init__(self, error_api=None, error_code=None, time_stamp=None, message=None, message_key=None):  # noqa: E501
        """ErrorResponseErrors - a model defined in Swagger"""  # noqa: E501
        self._error_api = None
        self._error_code = None
        self._time_stamp = None
        self._message = None
        self._message_key = None
        self.discriminator = None
        if error_api is not None:
            self.error_api = error_api
        if error_code is not None:
            self.error_code = error_code
        if time_stamp is not None:
            self.time_stamp = time_stamp
        if message is not None:
            self.message = message
        if message_key is not None:
            self.message_key = message_key

    @property
    def error_api(self):
        """Gets the error_api of this ErrorResponseErrors.  # noqa: E501

        Status returned by the API.  # noqa: E501

        :return: The error_api of this ErrorResponseErrors.  # noqa: E501
        :rtype: str
        """
        return self._error_api

    @error_api.setter
    def error_api(self, error_api):
        """Sets the error_api of this ErrorResponseErrors.

        Status returned by the API.  # noqa: E501

        :param error_api: The error_api of this ErrorResponseErrors.  # noqa: E501
        :type: str
        """

        self._error_api = error_api

    @property
    def error_code(self):
        """Gets the error_code of this ErrorResponseErrors.  # noqa: E501

        ErrorCode by the API.  # noqa: E501

        :return: The error_code of this ErrorResponseErrors.  # noqa: E501
        :rtype: str
        """
        return self._error_code

    @error_code.setter
    def error_code(self, error_code):
        """Sets the error_code of this ErrorResponseErrors.

        ErrorCode by the API.  # noqa: E501

        :param error_code: The error_code of this ErrorResponseErrors.  # noqa: E501
        :type: str
        """

        self._error_code = error_code

    @property
    def time_stamp(self):
        """Gets the time_stamp of this ErrorResponseErrors.  # noqa: E501

        TimeStamp.  # noqa: E501

        :return: The time_stamp of this ErrorResponseErrors.  # noqa: E501
        :rtype: str
        """
        return self._time_stamp

    @time_stamp.setter
    def time_stamp(self, time_stamp):
        """Sets the time_stamp of this ErrorResponseErrors.

        TimeStamp.  # noqa: E501

        :param time_stamp: The time_stamp of this ErrorResponseErrors.  # noqa: E501
        :type: str
        """

        self._time_stamp = time_stamp

    @property
    def message(self):
        """Gets the message of this ErrorResponseErrors.  # noqa: E501

        Error message.  # noqa: E501

        :return: The message of this ErrorResponseErrors.  # noqa: E501
        :rtype: str
        """
        return self._message

    @message.setter
    def message(self, message):
        """Sets the message of this ErrorResponseErrors.

        Error message.  # noqa: E501

        :param message: The message of this ErrorResponseErrors.  # noqa: E501
        :type: str
        """

        self._message = message

    @property
    def message_key(self):
        """Gets the message_key of this ErrorResponseErrors.  # noqa: E501

        Error message key.  # noqa: E501

        :return: The message_key of this ErrorResponseErrors.  # noqa: E501
        :rtype: str
        """
        return self._message_key

    @message_key.setter
    def message_key(self, message_key):
        """Sets the message_key of this ErrorResponseErrors.

        Error message key.  # noqa: E501

        :param message_key: The message_key of this ErrorResponseErrors.  # noqa: E501
        :type: str
        """

        self._message_key = message_key

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(ErrorResponseErrors, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ErrorResponseErrors):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    apply-api

    The Apply API allows for seamless integration of the Phenom systems, enabling partners to push applications directly. This API also enables partners to integrate the Phenom Quick application process into their own job boards, while still maintaining control over the candidate experience. As a result, candidates can submit their applications without needing to visit the customer career site.  # noqa: E501

    OpenAPI spec version: 2.0.0
    
    Generated by: phenom
"""

import pprint
import re  # noqa: F401

import six

class EducationData(object):
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'school_name': 'str',
        'degree': 'str',
        'field_of_study': 'str',
        'grade_average': 'str',
        'from_to': 'FromTo'
    }

    attribute_map = {
        'school_name': 'schoolName',
        'degree': 'degree',
        'field_of_study': 'fieldOfStudy',
        'grade_average': 'gradeAverage',
        'from_to': 'fromTo'
    }

    def __init__(self, school_name=None, degree=None, field_of_study=None, grade_average=None, from_to=None):  # noqa: E501
        """EducationData - a model defined in Swagger"""  # noqa: E501
        self._school_name = None
        self._degree = None
        self._field_of_study = None
        self._grade_average = None
        self._from_to = None
        self.discriminator = None
        self.school_name = school_name
        self.degree = degree
        if field_of_study is not None:
            self.field_of_study = field_of_study
        if grade_average is not None:
            self.grade_average = grade_average
        if from_to is not None:
            self.from_to = from_to

    @property
    def school_name(self):
        """Gets the school_name of this EducationData.  # noqa: E501

        School/College/Institution Name.  # noqa: E501

        :return: The school_name of this EducationData.  # noqa: E501
        :rtype: str
        """
        return self._school_name

    @school_name.setter
    def school_name(self, school_name):
        """Sets the school_name of this EducationData.

        School/College/Institution Name.  # noqa: E501

        :param school_name: The school_name of this EducationData.  # noqa: E501
        :type: str
        """
        if school_name is None:
            raise ValueError("Invalid value for `school_name`, must not be `None`")  # noqa: E501

        self._school_name = school_name

    @property
    def degree(self):
        """Gets the degree of this EducationData.  # noqa: E501

        Degree you have majored in.  # noqa: E501

        :return: The degree of this EducationData.  # noqa: E501
        :rtype: str
        """
        return self._degree

    @degree.setter
    def degree(self, degree):
        """Sets the degree of this EducationData.

        Degree you have majored in.  # noqa: E501

        :param degree: The degree of this EducationData.  # noqa: E501
        :type: str
        """
        if degree is None:
            raise ValueError("Invalid value for `degree`, must not be `None`")  # noqa: E501

        self._degree = degree

    @property
    def field_of_study(self):
        """Gets the field_of_study of this EducationData.  # noqa: E501

        Specialization/Field of Study.  # noqa: E501

        :return: The field_of_study of this EducationData.  # noqa: E501
        :rtype: str
        """
        return self._field_of_study

    @field_of_study.setter
    def field_of_study(self, field_of_study):
        """Sets the field_of_study of this EducationData.

        Specialization/Field of Study.  # noqa: E501

        :param field_of_study: The field_of_study of this EducationData.  # noqa: E501
        :type: str
        """

        self._field_of_study = field_of_study

    @property
    def grade_average(self):
        """Gets the grade_average of this EducationData.  # noqa: E501

        Grade Average/CGPA/Percentage.  # noqa: E501

        :return: The grade_average of this EducationData.  # noqa: E501
        :rtype: str
        """
        return self._grade_average

    @grade_average.setter
    def grade_average(self, grade_average):
        """Sets the grade_average of this EducationData.

        Grade Average/CGPA/Percentage.  # noqa: E501

        :param grade_average: The grade_average of this EducationData.  # noqa: E501
        :type: str
        """

        self._grade_average = grade_average

    @property
    def from_to(self):
        """Gets the from_to of this EducationData.  # noqa: E501


        :return: The from_to of this EducationData.  # noqa: E501
        :rtype: FromTo
        """
        return self._from_to

    @from_to.setter
    def from_to(self, from_to):
        """Sets the from_to of this EducationData.


        :param from_to: The from_to of this EducationData.  # noqa: E501
        :type: FromTo
        """

        self._from_to = from_to

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(EducationData, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, EducationData):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



from phenom.entity.ai_matching import AIMatching
from phenom.entity.applications import Applications
from phenom.entity.applicants import Applicants
from phenom.entity.campaigns import Campaigns
from phenom.entity.candidate import Candidate
from phenom.entity.communications import Communications
from phenom.entity.interview_screening import InterviewScreening
from phenom.entity.employees import Employees
from phenom.entity.evaluations import Evaluations
from phenom.entity.hiring_manager import HiringManager
from phenom.entity.jobs import Jobs
from phenom.entity.projects import Projects
from phenom.entity.parsers import Parsers
from phenom.entity.prediction import Prediction
from phenom.entity.tags import Tags
from phenom.entity.user_management import UserManagement

from phenom.commons.get_token import tokengeneration
class Authorization(object):
    def __init__(self, url, client_id, client_secret, gateway_url, apikey=None):
        self.__url = url
        self.__client_id = client_id
        self.__client_secret = client_secret
        self.__gateway_url = gateway_url
        self.__apikey = apikey

    def token(self):
        return tokengeneration(self.__url, self.__client_id, self.__client_secret)

    def ai_matching(self):
        return AIMatching(self.token(), self.__gateway_url, self.__apikey)
    def applications(self):
        return Applications(self.token(), self.__gateway_url, self.__apikey)
    def applicants(self):
        return Applicants(self.token(), self.__gateway_url, self.__apikey)
    def campaigns(self):
        return Campaigns(self.token(), self.__gateway_url, self.__apikey)
    def candidate(self):
        return Candidate(self.token(), self.__gateway_url, self.__apikey)
    def communications(self):
        return Communications(self.token(), self.__gateway_url, self.__apikey)
    def interview_screening(self):
        return InterviewScreening(self.token(), self.__gateway_url, self.__apikey)
    def employees(self):
        return Employees(self.token(), self.__gateway_url, self.__apikey)
    def evaluations(self):
        return Evaluations(self.token(), self.__gateway_url, self.__apikey)
    def hiring_manager(self):
        return HiringManager(self.token(), self.__gateway_url, self.__apikey)
    def jobs(self):
        return Jobs(self.token(), self.__gateway_url, self.__apikey)
    def projects(self):
        return Projects(self.token(), self.__gateway_url, self.__apikey)
    def parsers(self):
        return Parsers(self.token(), self.__gateway_url, self.__apikey)
    def prediction(self):
        return Prediction(self.token(), self.__gateway_url, self.__apikey)
    def tags(self):
        return Tags(self.token(), self.__gateway_url, self.__apikey)
    def user_management(self):
        return UserManagement(self.token(), self.__gateway_url, self.__apikey)


# coding: utf-8

"""
    candidates-api

    The Candidate APIs allows you to add, update and delete candidates.  # noqa: E501

    OpenAPI spec version: 1.0.0
    
    Generated by: phenom
"""

import pprint
import re  # noqa: F401

import six

class ExperienceDataExperiences(object):
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'company': 'str',
        'job_title': 'str',
        'industry': 'str',
        'role': 'str',
        'job_location': 'str',
        'start_date': 'float',
        'end_date': 'float',
        'is_current': 'bool',
        'company_url': 'str',
        'job_summary': 'str'
    }

    attribute_map = {
        'company': 'company',
        'job_title': 'jobTitle',
        'industry': 'industry',
        'role': 'role',
        'job_location': 'jobLocation',
        'start_date': 'startDate',
        'end_date': 'endDate',
        'is_current': 'isCurrent',
        'company_url': 'companyUrl',
        'job_summary': 'jobSummary'
    }

    def __init__(self, company=None, job_title=None, industry=None, role=None, job_location=None, start_date=None, end_date=None, is_current=None, company_url=None, job_summary=None):  # noqa: E501
        """ExperienceDataExperiences - a model defined in Swagger"""  # noqa: E501
        self._company = None
        self._job_title = None
        self._industry = None
        self._role = None
        self._job_location = None
        self._start_date = None
        self._end_date = None
        self._is_current = None
        self._company_url = None
        self._job_summary = None
        self.discriminator = None
        if company is not None:
            self.company = company
        if job_title is not None:
            self.job_title = job_title
        if industry is not None:
            self.industry = industry
        if role is not None:
            self.role = role
        if job_location is not None:
            self.job_location = job_location
        if start_date is not None:
            self.start_date = start_date
        if end_date is not None:
            self.end_date = end_date
        if is_current is not None:
            self.is_current = is_current
        if company_url is not None:
            self.company_url = company_url
        if job_summary is not None:
            self.job_summary = job_summary

    @property
    def company(self):
        """Gets the company of this ExperienceDataExperiences.  # noqa: E501

        A string representing the name of the company.  # noqa: E501

        :return: The company of this ExperienceDataExperiences.  # noqa: E501
        :rtype: str
        """
        return self._company

    @company.setter
    def company(self, company):
        """Sets the company of this ExperienceDataExperiences.

        A string representing the name of the company.  # noqa: E501

        :param company: The company of this ExperienceDataExperiences.  # noqa: E501
        :type: str
        """

        self._company = company

    @property
    def job_title(self):
        """Gets the job_title of this ExperienceDataExperiences.  # noqa: E501

        A string representing the job title.  # noqa: E501

        :return: The job_title of this ExperienceDataExperiences.  # noqa: E501
        :rtype: str
        """
        return self._job_title

    @job_title.setter
    def job_title(self, job_title):
        """Sets the job_title of this ExperienceDataExperiences.

        A string representing the job title.  # noqa: E501

        :param job_title: The job_title of this ExperienceDataExperiences.  # noqa: E501
        :type: str
        """

        self._job_title = job_title

    @property
    def industry(self):
        """Gets the industry of this ExperienceDataExperiences.  # noqa: E501

        A string representing the industry associated with the experience.  # noqa: E501

        :return: The industry of this ExperienceDataExperiences.  # noqa: E501
        :rtype: str
        """
        return self._industry

    @industry.setter
    def industry(self, industry):
        """Sets the industry of this ExperienceDataExperiences.

        A string representing the industry associated with the experience.  # noqa: E501

        :param industry: The industry of this ExperienceDataExperiences.  # noqa: E501
        :type: str
        """

        self._industry = industry

    @property
    def role(self):
        """Gets the role of this ExperienceDataExperiences.  # noqa: E501

        A string representing the role in the experience.  # noqa: E501

        :return: The role of this ExperienceDataExperiences.  # noqa: E501
        :rtype: str
        """
        return self._role

    @role.setter
    def role(self, role):
        """Sets the role of this ExperienceDataExperiences.

        A string representing the role in the experience.  # noqa: E501

        :param role: The role of this ExperienceDataExperiences.  # noqa: E501
        :type: str
        """

        self._role = role

    @property
    def job_location(self):
        """Gets the job_location of this ExperienceDataExperiences.  # noqa: E501

        A string representing the location of the job.  # noqa: E501

        :return: The job_location of this ExperienceDataExperiences.  # noqa: E501
        :rtype: str
        """
        return self._job_location

    @job_location.setter
    def job_location(self, job_location):
        """Sets the job_location of this ExperienceDataExperiences.

        A string representing the location of the job.  # noqa: E501

        :param job_location: The job_location of this ExperienceDataExperiences.  # noqa: E501
        :type: str
        """

        self._job_location = job_location

    @property
    def start_date(self):
        """Gets the start_date of this ExperienceDataExperiences.  # noqa: E501

        A number representing the start date of the experience.  # noqa: E501

        :return: The start_date of this ExperienceDataExperiences.  # noqa: E501
        :rtype: float
        """
        return self._start_date

    @start_date.setter
    def start_date(self, start_date):
        """Sets the start_date of this ExperienceDataExperiences.

        A number representing the start date of the experience.  # noqa: E501

        :param start_date: The start_date of this ExperienceDataExperiences.  # noqa: E501
        :type: float
        """

        self._start_date = start_date

    @property
    def end_date(self):
        """Gets the end_date of this ExperienceDataExperiences.  # noqa: E501

        A number representing the end date of the experience.  # noqa: E501

        :return: The end_date of this ExperienceDataExperiences.  # noqa: E501
        :rtype: float
        """
        return self._end_date

    @end_date.setter
    def end_date(self, end_date):
        """Sets the end_date of this ExperienceDataExperiences.

        A number representing the end date of the experience.  # noqa: E501

        :param end_date: The end_date of this ExperienceDataExperiences.  # noqa: E501
        :type: float
        """

        self._end_date = end_date

    @property
    def is_current(self):
        """Gets the is_current of this ExperienceDataExperiences.  # noqa: E501

        A boolean indicating whether the experience is current.  # noqa: E501

        :return: The is_current of this ExperienceDataExperiences.  # noqa: E501
        :rtype: bool
        """
        return self._is_current

    @is_current.setter
    def is_current(self, is_current):
        """Sets the is_current of this ExperienceDataExperiences.

        A boolean indicating whether the experience is current.  # noqa: E501

        :param is_current: The is_current of this ExperienceDataExperiences.  # noqa: E501
        :type: bool
        """

        self._is_current = is_current

    @property
    def company_url(self):
        """Gets the company_url of this ExperienceDataExperiences.  # noqa: E501

        A string representing the URL of the company.  # noqa: E501

        :return: The company_url of this ExperienceDataExperiences.  # noqa: E501
        :rtype: str
        """
        return self._company_url

    @company_url.setter
    def company_url(self, company_url):
        """Sets the company_url of this ExperienceDataExperiences.

        A string representing the URL of the company.  # noqa: E501

        :param company_url: The company_url of this ExperienceDataExperiences.  # noqa: E501
        :type: str
        """

        self._company_url = company_url

    @property
    def job_summary(self):
        """Gets the job_summary of this ExperienceDataExperiences.  # noqa: E501

        A string representing a summary of the job experience.  # noqa: E501

        :return: The job_summary of this ExperienceDataExperiences.  # noqa: E501
        :rtype: str
        """
        return self._job_summary

    @job_summary.setter
    def job_summary(self, job_summary):
        """Sets the job_summary of this ExperienceDataExperiences.

        A string representing a summary of the job experience.  # noqa: E501

        :param job_summary: The job_summary of this ExperienceDataExperiences.  # noqa: E501
        :type: str
        """

        self._job_summary = job_summary

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(ExperienceDataExperiences, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ExperienceDataExperiences):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    projects-api

    These APIs allows you to create workflow statuses, which are then assigned to workflows. These workflows, containing multiple statuses, are subsequently linked to projects. Additionally, candidates are associated with projects, defining the path they are meant to follow within the established workflows.  # noqa: E501

    OpenAPI spec version: 1.0.0
    
    Generated by: phenom
"""

from __future__ import absolute_import

import re  # noqa: F401

# python 2 and python 3 compatibility library
import six

from phenom.commons.api_client import ApiClient


class WorkflowStatusApi(object):
    base_path = "/projects-api"  # your base path

    def __init__(self, token, gateway_url, apikey, api_client=None):
        if api_client is None:
            api_client = ApiClient(gateway_url + self.base_path, apikey, token)
        self.api_client = api_client

    def create_workflow_status(self, body, x_ph_userid, **kwargs):  # noqa: E501
        """Create Workflow-Status  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.create_workflow_status(body, x_ph_userid, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param CreateWorkflowStatusRequest body: Create workflow status (required)
        :param str x_ph_userid: (required)
        :return: CreationResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.create_workflow_status_with_http_info(body, x_ph_userid, **kwargs)  # noqa: E501
        else:
            (data) = self.create_workflow_status_with_http_info(body, x_ph_userid, **kwargs)  # noqa: E501
            return data

    def create_workflow_status_with_http_info(self, body, x_ph_userid, **kwargs):  # noqa: E501
        """Create Workflow-Status  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.create_workflow_status_with_http_info(body, x_ph_userid, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param CreateWorkflowStatusRequest body: Create workflow status (required)
        :param str x_ph_userid: (required)
        :return: CreationResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['body', 'x_ph_userid']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method create_workflow_status" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'body' is set
        if ('body' not in params or
                params['body'] is None):
            raise ValueError("Missing the required parameter `body` when calling `create_workflow_status`")  # noqa: E501
        # verify the required parameter 'x_ph_userid' is set
        if ('x_ph_userid' not in params or
                params['x_ph_userid'] is None):
            raise ValueError("Missing the required parameter `x_ph_userid` when calling `create_workflow_status`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}
        if 'x_ph_userid' in params:
            header_params['x-ph-userid'] = params['x_ph_userid']  # noqa: E501

        form_params = []
        local_var_files = {}

        body_params = None
        if 'body' in params:
            body_params = params['body']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/v1/workflow-statuses', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='CreationResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def delete_workflow_status(self, status_id, x_ph_userid, **kwargs):  # noqa: E501
        """Delete Workflow-Status  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.delete_workflow_status(status_id, x_ph_userid, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str status_id: statusId (required)
        :param str x_ph_userid: (required)
        :return: DeleteWorkflowStatusResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.delete_workflow_status_with_http_info(status_id, x_ph_userid, **kwargs)  # noqa: E501
        else:
            (data) = self.delete_workflow_status_with_http_info(status_id, x_ph_userid, **kwargs)  # noqa: E501
            return data

    def delete_workflow_status_with_http_info(self, status_id, x_ph_userid, **kwargs):  # noqa: E501
        """Delete Workflow-Status  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.delete_workflow_status_with_http_info(status_id, x_ph_userid, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str status_id: statusId (required)
        :param str x_ph_userid: (required)
        :return: DeleteWorkflowStatusResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['status_id', 'x_ph_userid']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method delete_workflow_status" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'status_id' is set
        if ('status_id' not in params or
                params['status_id'] is None):
            raise ValueError("Missing the required parameter `status_id` when calling `delete_workflow_status`")  # noqa: E501
        # verify the required parameter 'x_ph_userid' is set
        if ('x_ph_userid' not in params or
                params['x_ph_userid'] is None):
            raise ValueError("Missing the required parameter `x_ph_userid` when calling `delete_workflow_status`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'status_id' in params:
            path_params['statusId'] = params['status_id']  # noqa: E501

        query_params = []

        header_params = {}
        if 'x_ph_userid' in params:
            header_params['x-ph-userid'] = params['x_ph_userid']  # noqa: E501

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/v1/workflow-statuses/{statusId}', 'DELETE',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='DeleteWorkflowStatusResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_workflow_status(self, x_ph_userid, **kwargs):  # noqa: E501
        """Get Workflow-Statuses  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_workflow_status(x_ph_userid, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str x_ph_userid: (required)
        :param int _from: The number of workflow-statuses to skip before starting to collect the result
        :param int size: size of the result
        :param str search_name: keyword to search
        :return: GetAllWorkflowStatusResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.get_workflow_status_with_http_info(x_ph_userid, **kwargs)  # noqa: E501
        else:
            (data) = self.get_workflow_status_with_http_info(x_ph_userid, **kwargs)  # noqa: E501
            return data

    def get_workflow_status_with_http_info(self, x_ph_userid, **kwargs):  # noqa: E501
        """Get Workflow-Statuses  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_workflow_status_with_http_info(x_ph_userid, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str x_ph_userid: (required)
        :param int _from: The number of workflow-statuses to skip before starting to collect the result
        :param int size: size of the result
        :param str search_name: keyword to search
        :return: GetAllWorkflowStatusResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['x_ph_userid', '_from', 'size', 'search_name']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_workflow_status" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'x_ph_userid' is set
        if ('x_ph_userid' not in params or
                params['x_ph_userid'] is None):
            raise ValueError("Missing the required parameter `x_ph_userid` when calling `get_workflow_status`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []
        if '_from' in params:
            query_params.append(('from', params['_from']))  # noqa: E501
        if 'size' in params:
            query_params.append(('size', params['size']))  # noqa: E501
        if 'search_name' in params:
            query_params.append(('searchName', params['search_name']))  # noqa: E501

        header_params = {}
        if 'x_ph_userid' in params:
            header_params['x-ph-userid'] = params['x_ph_userid']  # noqa: E501

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/v1/workflow-statuses', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='GetAllWorkflowStatusResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_workflow_status_with_id(self, status_id, x_ph_userid, **kwargs):  # noqa: E501
        """Get Workflow by statusId  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_workflow_status_with_id(status_id, x_ph_userid, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str status_id: statusId (required)
        :param str x_ph_userid: (required)
        :return: GetWorkflowStatusResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.get_workflow_status_with_id_with_http_info(status_id, x_ph_userid, **kwargs)  # noqa: E501
        else:
            (data) = self.get_workflow_status_with_id_with_http_info(status_id, x_ph_userid, **kwargs)  # noqa: E501
            return data

    def get_workflow_status_with_id_with_http_info(self, status_id, x_ph_userid, **kwargs):  # noqa: E501
        """Get Workflow by statusId  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_workflow_status_with_id_with_http_info(status_id, x_ph_userid, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str status_id: statusId (required)
        :param str x_ph_userid: (required)
        :return: GetWorkflowStatusResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['status_id', 'x_ph_userid']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_workflow_status_with_id" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'status_id' is set
        if ('status_id' not in params or
                params['status_id'] is None):
            raise ValueError("Missing the required parameter `status_id` when calling `get_workflow_status_with_id`")  # noqa: E501
        # verify the required parameter 'x_ph_userid' is set
        if ('x_ph_userid' not in params or
                params['x_ph_userid'] is None):
            raise ValueError("Missing the required parameter `x_ph_userid` when calling `get_workflow_status_with_id`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'status_id' in params:
            path_params['statusId'] = params['status_id']  # noqa: E501

        query_params = []

        header_params = {}
        if 'x_ph_userid' in params:
            header_params['x-ph-userid'] = params['x_ph_userid']  # noqa: E501

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/v1/workflow-statuses/{statusId}', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='GetWorkflowStatusResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)



# coding: utf-8

"""
    projects-api

    These APIs allows you to create workflow statuses, which are then assigned to workflows. These workflows, containing multiple statuses, are subsequently linked to projects. Additionally, candidates are associated with projects, defining the path they are meant to follow within the established workflows.  # noqa: E501

    OpenAPI spec version: 1.0.0
    
    Generated by: phenom
"""

import pprint
import re  # noqa: F401

import six

class DeleteWorkflowStatusResponse(object):
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'status': 'str',
        'message': 'str',
        'timestamp': 'str'
    }

    attribute_map = {
        'status': 'status',
        'message': 'message',
        'timestamp': 'timestamp'
    }

    def __init__(self, status=None, message=None, timestamp=None):  # noqa: E501
        """DeleteWorkflowStatusResponse - a model defined in Swagger"""  # noqa: E501
        self._status = None
        self._message = None
        self._timestamp = None
        self.discriminator = None
        self.status = status
        self.message = message
        self.timestamp = timestamp

    @property
    def status(self):
        """Gets the status of this DeleteWorkflowStatusResponse.  # noqa: E501

        Status of the response.  # noqa: E501

        :return: The status of this DeleteWorkflowStatusResponse.  # noqa: E501
        :rtype: str
        """
        return self._status

    @status.setter
    def status(self, status):
        """Sets the status of this DeleteWorkflowStatusResponse.

        Status of the response.  # noqa: E501

        :param status: The status of this DeleteWorkflowStatusResponse.  # noqa: E501
        :type: str
        """
        if status is None:
            raise ValueError("Invalid value for `status`, must not be `None`")  # noqa: E501

        self._status = status

    @property
    def message(self):
        """Gets the message of this DeleteWorkflowStatusResponse.  # noqa: E501

        Message associated with the response.  # noqa: E501

        :return: The message of this DeleteWorkflowStatusResponse.  # noqa: E501
        :rtype: str
        """
        return self._message

    @message.setter
    def message(self, message):
        """Sets the message of this DeleteWorkflowStatusResponse.

        Message associated with the response.  # noqa: E501

        :param message: The message of this DeleteWorkflowStatusResponse.  # noqa: E501
        :type: str
        """
        if message is None:
            raise ValueError("Invalid value for `message`, must not be `None`")  # noqa: E501

        self._message = message

    @property
    def timestamp(self):
        """Gets the timestamp of this DeleteWorkflowStatusResponse.  # noqa: E501

        Timestamp of the response.  # noqa: E501

        :return: The timestamp of this DeleteWorkflowStatusResponse.  # noqa: E501
        :rtype: str
        """
        return self._timestamp

    @timestamp.setter
    def timestamp(self, timestamp):
        """Sets the timestamp of this DeleteWorkflowStatusResponse.

        Timestamp of the response.  # noqa: E501

        :param timestamp: The timestamp of this DeleteWorkflowStatusResponse.  # noqa: E501
        :type: str
        """
        if timestamp is None:
            raise ValueError("Invalid value for `timestamp`, must not be `None`")  # noqa: E501

        self._timestamp = timestamp

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(DeleteWorkflowStatusResponse, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, DeleteWorkflowStatusResponse):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

# flake8: noqa
"""
    candidates-api

    The Candidate APIs allows you to add, update and delete candidates.  # noqa: E501

    OpenAPI spec version: 1.0.0
    
    Generated by: phenom
"""

from __future__ import absolute_import

# import models into model package
from phenom.api.candidates.models.add_or_update_education_request import AddOrUpdateEducationRequest
from phenom.api.candidates.models.add_or_update_education_request_education import AddOrUpdateEducationRequestEducation
from phenom.api.candidates.models.add_or_update_experience_request import AddOrUpdateExperienceRequest
from phenom.api.candidates.models.add_or_update_experience_request_experience import AddOrUpdateExperienceRequestExperience
from phenom.api.candidates.models.add_skills_request import AddSkillsRequest
from phenom.api.candidates.models.add_skills_request_skill_list import AddSkillsRequestSkillList
from phenom.api.candidates.models.additional_fields import AdditionalFields
from phenom.api.candidates.models.additional_fields_data import AdditionalFieldsData
from phenom.api.candidates.models.additional_fields_update_response import AdditionalFieldsUpdateResponse
from phenom.api.candidates.models.address import Address
from phenom.api.candidates.models.address_data import AddressData
from phenom.api.candidates.models.address_data_address import AddressDataAddress
from phenom.api.candidates.models.address_update_response import AddressUpdateResponse
from phenom.api.candidates.models.award import Award
from phenom.api.candidates.models.award_data import AwardData
from phenom.api.candidates.models.award_data_awarded_on import AwardDataAwardedOn
from phenom.api.candidates.models.award_data_awards import AwardDataAwards
from phenom.api.candidates.models.candidate import Candidate
from phenom.api.candidates.models.candidate_create_response import CandidateCreateResponse
from phenom.api.candidates.models.candidate_create_response_data import CandidateCreateResponseData
from phenom.api.candidates.models.candidate_data import CandidateData
from phenom.api.candidates.models.candidate_data_candidate import CandidateDataCandidate
from phenom.api.candidates.models.candidate_data_candidate_attachments import CandidateDataCandidateAttachments
from phenom.api.candidates.models.candidate_data_candidate_contacts import CandidateDataCandidateContacts
from phenom.api.candidates.models.candidate_data_candidate_email_list import CandidateDataCandidateEmailList
from phenom.api.candidates.models.candidate_data_candidate_experience import CandidateDataCandidateExperience
from phenom.api.candidates.models.candidate_data_candidate_new_location import CandidateDataCandidateNewLocation
from phenom.api.candidates.models.candidate_data_candidate_preferred_communication_mode import CandidateDataCandidatePreferredCommunicationMode
from phenom.api.candidates.models.candidate_details_update_response import CandidateDetailsUpdateResponse
from phenom.api.candidates.models.certification import Certification
from phenom.api.candidates.models.certification_data import CertificationData
from phenom.api.candidates.models.certification_data_certifications import CertificationDataCertifications
from phenom.api.candidates.models.certification_data_expiry_date import CertificationDataExpiryDate
from phenom.api.candidates.models.certification_data_issued_date import CertificationDataIssuedDate
from phenom.api.candidates.models.create_candidate_request import CreateCandidateRequest
from phenom.api.candidates.models.create_candidate_request_contacts import CreateCandidateRequestContacts
from phenom.api.candidates.models.create_candidate_request_email_list import CreateCandidateRequestEmailList
from phenom.api.candidates.models.education import Education
from phenom.api.candidates.models.education_data import EducationData
from phenom.api.candidates.models.education_data_educations import EducationDataEducations
from phenom.api.candidates.models.error import Error
from phenom.api.candidates.models.error_message import ErrorMessage
from phenom.api.candidates.models.experience import Experience
from phenom.api.candidates.models.experience_data import ExperienceData
from phenom.api.candidates.models.experience_data_experiences import ExperienceDataExperiences
from phenom.api.candidates.models.preferred_location import PreferredLocation
from phenom.api.candidates.models.preferred_location_data import PreferredLocationData
from phenom.api.candidates.models.preferred_location_data_preferred_location_list import PreferredLocationDataPreferredLocationList
from phenom.api.candidates.models.preferred_location_update_response import PreferredLocationUpdateResponse
from phenom.api.candidates.models.recommendations import Recommendations
from phenom.api.candidates.models.recommendations_data import RecommendationsData
from phenom.api.candidates.models.recommendations_data_recommendations import RecommendationsDataRecommendations
from phenom.api.candidates.models.recommendations_update_response import RecommendationsUpdateResponse
from phenom.api.candidates.models.skills import Skills
from phenom.api.candidates.models.skills_data import SkillsData
from phenom.api.candidates.models.skills_data_skills import SkillsDataSkills
from phenom.api.candidates.models.update_additional_fields_request import UpdateAdditionalFieldsRequest
from phenom.api.candidates.models.update_address_request import UpdateAddressRequest
from phenom.api.candidates.models.update_address_request_address_logs import UpdateAddressRequestAddressLogs
from phenom.api.candidates.models.update_awards_request import UpdateAwardsRequest
from phenom.api.candidates.models.update_awards_request_awarded_on import UpdateAwardsRequestAwardedOn
from phenom.api.candidates.models.update_awards_request_awards import UpdateAwardsRequestAwards
from phenom.api.candidates.models.update_candidate_request import UpdateCandidateRequest
from phenom.api.candidates.models.update_candidate_request_contacts import UpdateCandidateRequestContacts
from phenom.api.candidates.models.update_candidate_request_email_list import UpdateCandidateRequestEmailList
from phenom.api.candidates.models.update_certification_request import UpdateCertificationRequest
from phenom.api.candidates.models.update_certification_request_certifications import UpdateCertificationRequestCertifications
from phenom.api.candidates.models.update_certification_request_expiry_date import UpdateCertificationRequestExpiryDate
from phenom.api.candidates.models.update_certification_request_issued_date import UpdateCertificationRequestIssuedDate
from phenom.api.candidates.models.update_preferred_location_request import UpdatePreferredLocationRequest
from phenom.api.candidates.models.update_preferred_location_request_preferred_location_list import UpdatePreferredLocationRequestPreferredLocationList
from phenom.api.candidates.models.update_recommendations_request import UpdateRecommendationsRequest
from phenom.api.candidates.models.update_recommendations_request_recommendations import UpdateRecommendationsRequestRecommendations



# coding: utf-8

# flake8: noqa

"""
    aisourcing-api

    AI matching FitScore provides a concise assessment indicating how well a candidate aligns with a job based on their skills, experience, and qualifications.  # noqa: E501

    OpenAPI spec version: 1.0.0
    
    Generated by: phenom
"""

from __future__ import absolute_import

# import apis into sdk package
from phenom.api.aisourcing.ai_matching_api import AIMatchingApi
# import ApiClient
from phenom.commons.api_client import ApiClient
from phenom.commons.configuration import Configuration
# import models into sdk package
from phenom.api.aisourcing.models.error_response import ErrorResponse
from phenom.api.aisourcing.models.fit_score_request import FitScoreRequest
from phenom.api.aisourcing.models.fitscore_bad_request import FitscoreBadRequest
from phenom.api.aisourcing.models.fitscore_response import FitscoreResponse
from phenom.api.aisourcing.models.fitscore_response_result import FitscoreResponseResult
from phenom.api.aisourcing.models.fitscore_response_skill_gap import FitscoreResponseSkillGap
from phenom.api.aisourcing.models.preferred_locations import PreferredLocations
from phenom.api.aisourcing.models.preferred_locations_latlong import PreferredLocationsLatlong
from phenom.api.aisourcing.models.skill_matching_bad_request import SkillMatchingBadRequest
from phenom.api.aisourcing.models.skill_matching_error_response import SkillMatchingErrorResponse
from phenom.api.aisourcing.models.skill_matching_response import SkillMatchingResponse
from phenom.api.aisourcing.models.user_profile_fit_score import UserProfileFitScore



# coding: utf-8

"""
    hrm-api

    Hiring Manager can view all the pending tasks and evaluate the interview if any pending interviews.  # noqa: E501

    OpenAPI spec version: 1.0.0
    
    Generated by: phenom
"""

import pprint
import re  # noqa: F401

import six

class JobDetails(object):
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'company_name': 'str',
        'language': 'str',
        'apply_count': 'float',
        'job_requirements': 'str',
        'job_title': 'str',
        'job_code': 'str',
        'source': 'str',
        'updated_date': 'str',
        'posted_date': 'str',
        'is_ever_green_req': 'str',
        'job_family': 'str',
        'agency_list': 'list[object]',
        'ats': 'str',
        'preferred_languages': 'list[object]',
        'posted_by': 'JobDetailsPostedBy',
        'posting_status': 'str',
        'fit_score_meta_data': 'JobDetailsFitScoreMetaData',
        'relation_type': 'JobDetailsRelationType',
        'description_teaser': 'str',
        'description': 'str',
        'job_url_map': 'object',
        'visibility_type': 'str',
        'site_type': 'str',
        'is_private': 'bool',
        'internal_category_id': 'str',
        'language_code': 'str',
        'hiring_manager': 'JobDetailsHiringManager',
        'multi_category': 'list[JobDetailsMultiCategory]',
        'publish_to': 'list[JobDetailsPublishTo]',
        'locale': 'str',
        'display_career_site': 'bool',
        'assigned': 'list[JobDetailsAssigned]',
        'job_zone': 'str',
        'multi_location': 'list[JobDetailsMultiLocation]',
        'job_merge_score': 'float',
        'benefits': 'str',
        'job_id': 'str',
        'job_category': 'str',
        'job_experience': 'str',
        'status': 'str',
        'tenant_specific_additional_fields': 'list[JobDetailsTenantSpecificAdditionalFields]',
        'visibility_locale': 'list[str]',
        'default': 'bool',
        'is_deleted': 'bool',
        'country_code': 'str',
        'candidates_in_process': 'float',
        'candidates_to_be_evaluated': 'float',
        'candidates_to_be_offered': 'float',
        'candidates_reviewed': 'float',
        'pending_candidates': 'float',
        'candidates_evaluated': 'float',
        'number_of_candidates': 'float',
        'interview_scheduled_count': 'float',
        'candidates_to_be_reviewed': 'float',
        'user_role': 'str',
        'company': 'str',
        'hashkey': 'str',
        'apply_url': 'str',
        'onet': 'list[JobDetailsOnet]',
        'variations': 'list[JobDetailsVariations]',
        'hiring_team_list': 'list[JobDetailsHiringTeamList]',
        'department': 'str',
        'job_type': 'str',
        'visibility_site_type': 'list[str]',
        'is_confidential': 'bool',
        'skills_and_experience': 'str',
        'scrape_time': 'str',
        'created_date': 'str',
        'job_visibility': 'str',
        'job_location': 'str',
        'publish': 'bool',
        'is_critical': 'bool',
        'hiring_manager_list': 'list[JobDetailsHiringManagerList]',
        'candidates_video_evaluated': 'float',
        'candidates_to_be_video_evaluated': 'float',
        'review_criteria_refinement_disabled': 'bool'
    }

    attribute_map = {
        'company_name': 'companyName',
        'language': 'language',
        'apply_count': 'applyCount',
        'job_requirements': 'jobRequirements',
        'job_title': 'jobTitle',
        'job_code': 'jobCode',
        'source': 'source',
        'updated_date': 'updatedDate',
        'posted_date': 'postedDate',
        'is_ever_green_req': 'isEverGreenReq',
        'job_family': 'jobFamily',
        'agency_list': 'agencyList',
        'ats': 'ats',
        'preferred_languages': 'preferred_languages',
        'posted_by': 'postedBy',
        'posting_status': 'postingStatus',
        'fit_score_meta_data': 'fitScoreMetaData',
        'relation_type': 'relation_type',
        'description_teaser': 'descriptionTeaser',
        'description': 'description',
        'job_url_map': 'jobUrlMap',
        'visibility_type': 'visibilityType',
        'site_type': 'siteType',
        'is_private': 'isPrivate',
        'internal_category_id': 'internalCategoryId',
        'language_code': 'languageCode',
        'hiring_manager': 'hiringManager',
        'multi_category': 'multi_category',
        'publish_to': 'publishTo',
        'locale': 'locale',
        'display_career_site': 'displayCareerSite',
        'assigned': 'assigned',
        'job_zone': 'job_zone',
        'multi_location': 'multi_location',
        'job_merge_score': 'jobMergeScore',
        'benefits': 'benefits',
        'job_id': 'jobId',
        'job_category': 'jobCategory',
        'job_experience': 'job_experience',
        'status': 'status',
        'tenant_specific_additional_fields': 'tenantSpecific_additionalFields',
        'visibility_locale': 'visibilityLocale',
        'default': 'default',
        'is_deleted': 'isDeleted',
        'country_code': 'countryCode',
        'candidates_in_process': 'candidatesInProcess',
        'candidates_to_be_evaluated': 'candidatesToBeEvaluated',
        'candidates_to_be_offered': 'candidatesToBeOffered',
        'candidates_reviewed': 'candidatesReviewed',
        'pending_candidates': 'pendingCandidates',
        'candidates_evaluated': 'candidatesEvaluated',
        'number_of_candidates': 'numberOfCandidates',
        'interview_scheduled_count': 'interviewScheduledCount',
        'candidates_to_be_reviewed': 'candidatesToBeReviewed',
        'user_role': 'userRole',
        'company': 'company',
        'hashkey': 'hashkey',
        'apply_url': 'applyUrl',
        'onet': 'onet',
        'variations': 'variations',
        'hiring_team_list': 'hiringTeamList',
        'department': 'department',
        'job_type': 'jobType',
        'visibility_site_type': 'visibilitySiteType',
        'is_confidential': 'isConfidential',
        'skills_and_experience': 'skillsAndExperience',
        'scrape_time': 'scrapeTime',
        'created_date': 'createdDate',
        'job_visibility': 'jobVisibility',
        'job_location': 'jobLocation',
        'publish': 'publish',
        'is_critical': 'isCritical',
        'hiring_manager_list': 'hiringManagerList',
        'candidates_video_evaluated': 'candidatesVideoEvaluated',
        'candidates_to_be_video_evaluated': 'candidatesToBeVideoEvaluated',
        'review_criteria_refinement_disabled': 'reviewCriteriaRefinementDisabled'
    }

    def __init__(self, company_name=None, language=None, apply_count=None, job_requirements=None, job_title=None, job_code=None, source=None, updated_date=None, posted_date=None, is_ever_green_req=None, job_family=None, agency_list=None, ats=None, preferred_languages=None, posted_by=None, posting_status=None, fit_score_meta_data=None, relation_type=None, description_teaser=None, description=None, job_url_map=None, visibility_type=None, site_type=None, is_private=None, internal_category_id=None, language_code=None, hiring_manager=None, multi_category=None, publish_to=None, locale=None, display_career_site=None, assigned=None, job_zone=None, multi_location=None, job_merge_score=None, benefits=None, job_id=None, job_category=None, job_experience=None, status=None, tenant_specific_additional_fields=None, visibility_locale=None, default=None, is_deleted=None, country_code=None, candidates_in_process=None, candidates_to_be_evaluated=None, candidates_to_be_offered=None, candidates_reviewed=None, pending_candidates=None, candidates_evaluated=None, number_of_candidates=None, interview_scheduled_count=None, candidates_to_be_reviewed=None, user_role=None, company=None, hashkey=None, apply_url=None, onet=None, variations=None, hiring_team_list=None, department=None, job_type=None, visibility_site_type=None, is_confidential=None, skills_and_experience=None, scrape_time=None, created_date=None, job_visibility=None, job_location=None, publish=None, is_critical=None, hiring_manager_list=None, candidates_video_evaluated=None, candidates_to_be_video_evaluated=None, review_criteria_refinement_disabled=None):  # noqa: E501
        """JobDetails - a model defined in Swagger"""  # noqa: E501
        self._company_name = None
        self._language = None
        self._apply_count = None
        self._job_requirements = None
        self._job_title = None
        self._job_code = None
        self._source = None
        self._updated_date = None
        self._posted_date = None
        self._is_ever_green_req = None
        self._job_family = None
        self._agency_list = None
        self._ats = None
        self._preferred_languages = None
        self._posted_by = None
        self._posting_status = None
        self._fit_score_meta_data = None
        self._relation_type = None
        self._description_teaser = None
        self._description = None
        self._job_url_map = None
        self._visibility_type = None
        self._site_type = None
        self._is_private = None
        self._internal_category_id = None
        self._language_code = None
        self._hiring_manager = None
        self._multi_category = None
        self._publish_to = None
        self._locale = None
        self._display_career_site = None
        self._assigned = None
        self._job_zone = None
        self._multi_location = None
        self._job_merge_score = None
        self._benefits = None
        self._job_id = None
        self._job_category = None
        self._job_experience = None
        self._status = None
        self._tenant_specific_additional_fields = None
        self._visibility_locale = None
        self._default = None
        self._is_deleted = None
        self._country_code = None
        self._candidates_in_process = None
        self._candidates_to_be_evaluated = None
        self._candidates_to_be_offered = None
        self._candidates_reviewed = None
        self._pending_candidates = None
        self._candidates_evaluated = None
        self._number_of_candidates = None
        self._interview_scheduled_count = None
        self._candidates_to_be_reviewed = None
        self._user_role = None
        self._company = None
        self._hashkey = None
        self._apply_url = None
        self._onet = None
        self._variations = None
        self._hiring_team_list = None
        self._department = None
        self._job_type = None
        self._visibility_site_type = None
        self._is_confidential = None
        self._skills_and_experience = None
        self._scrape_time = None
        self._created_date = None
        self._job_visibility = None
        self._job_location = None
        self._publish = None
        self._is_critical = None
        self._hiring_manager_list = None
        self._candidates_video_evaluated = None
        self._candidates_to_be_video_evaluated = None
        self._review_criteria_refinement_disabled = None
        self.discriminator = None
        if company_name is not None:
            self.company_name = company_name
        if language is not None:
            self.language = language
        if apply_count is not None:
            self.apply_count = apply_count
        if job_requirements is not None:
            self.job_requirements = job_requirements
        if job_title is not None:
            self.job_title = job_title
        if job_code is not None:
            self.job_code = job_code
        if source is not None:
            self.source = source
        if updated_date is not None:
            self.updated_date = updated_date
        if posted_date is not None:
            self.posted_date = posted_date
        if is_ever_green_req is not None:
            self.is_ever_green_req = is_ever_green_req
        if job_family is not None:
            self.job_family = job_family
        if agency_list is not None:
            self.agency_list = agency_list
        if ats is not None:
            self.ats = ats
        if preferred_languages is not None:
            self.preferred_languages = preferred_languages
        if posted_by is not None:
            self.posted_by = posted_by
        if posting_status is not None:
            self.posting_status = posting_status
        if fit_score_meta_data is not None:
            self.fit_score_meta_data = fit_score_meta_data
        if relation_type is not None:
            self.relation_type = relation_type
        if description_teaser is not None:
            self.description_teaser = description_teaser
        if description is not None:
            self.description = description
        if job_url_map is not None:
            self.job_url_map = job_url_map
        if visibility_type is not None:
            self.visibility_type = visibility_type
        if site_type is not None:
            self.site_type = site_type
        if is_private is not None:
            self.is_private = is_private
        if internal_category_id is not None:
            self.internal_category_id = internal_category_id
        if language_code is not None:
            self.language_code = language_code
        if hiring_manager is not None:
            self.hiring_manager = hiring_manager
        if multi_category is not None:
            self.multi_category = multi_category
        if publish_to is not None:
            self.publish_to = publish_to
        if locale is not None:
            self.locale = locale
        if display_career_site is not None:
            self.display_career_site = display_career_site
        if assigned is not None:
            self.assigned = assigned
        if job_zone is not None:
            self.job_zone = job_zone
        if multi_location is not None:
            self.multi_location = multi_location
        if job_merge_score is not None:
            self.job_merge_score = job_merge_score
        if benefits is not None:
            self.benefits = benefits
        if job_id is not None:
            self.job_id = job_id
        if job_category is not None:
            self.job_category = job_category
        if job_experience is not None:
            self.job_experience = job_experience
        if status is not None:
            self.status = status
        if tenant_specific_additional_fields is not None:
            self.tenant_specific_additional_fields = tenant_specific_additional_fields
        if visibility_locale is not None:
            self.visibility_locale = visibility_locale
        if default is not None:
            self.default = default
        if is_deleted is not None:
            self.is_deleted = is_deleted
        if country_code is not None:
            self.country_code = country_code
        if candidates_in_process is not None:
            self.candidates_in_process = candidates_in_process
        if candidates_to_be_evaluated is not None:
            self.candidates_to_be_evaluated = candidates_to_be_evaluated
        if candidates_to_be_offered is not None:
            self.candidates_to_be_offered = candidates_to_be_offered
        if candidates_reviewed is not None:
            self.candidates_reviewed = candidates_reviewed
        if pending_candidates is not None:
            self.pending_candidates = pending_candidates
        if candidates_evaluated is not None:
            self.candidates_evaluated = candidates_evaluated
        if number_of_candidates is not None:
            self.number_of_candidates = number_of_candidates
        if interview_scheduled_count is not None:
            self.interview_scheduled_count = interview_scheduled_count
        if candidates_to_be_reviewed is not None:
            self.candidates_to_be_reviewed = candidates_to_be_reviewed
        if user_role is not None:
            self.user_role = user_role
        if company is not None:
            self.company = company
        if hashkey is not None:
            self.hashkey = hashkey
        if apply_url is not None:
            self.apply_url = apply_url
        if onet is not None:
            self.onet = onet
        if variations is not None:
            self.variations = variations
        if hiring_team_list is not None:
            self.hiring_team_list = hiring_team_list
        if department is not None:
            self.department = department
        if job_type is not None:
            self.job_type = job_type
        if visibility_site_type is not None:
            self.visibility_site_type = visibility_site_type
        if is_confidential is not None:
            self.is_confidential = is_confidential
        if skills_and_experience is not None:
            self.skills_and_experience = skills_and_experience
        if scrape_time is not None:
            self.scrape_time = scrape_time
        if created_date is not None:
            self.created_date = created_date
        if job_visibility is not None:
            self.job_visibility = job_visibility
        if job_location is not None:
            self.job_location = job_location
        if publish is not None:
            self.publish = publish
        if is_critical is not None:
            self.is_critical = is_critical
        if hiring_manager_list is not None:
            self.hiring_manager_list = hiring_manager_list
        if candidates_video_evaluated is not None:
            self.candidates_video_evaluated = candidates_video_evaluated
        if candidates_to_be_video_evaluated is not None:
            self.candidates_to_be_video_evaluated = candidates_to_be_video_evaluated
        if review_criteria_refinement_disabled is not None:
            self.review_criteria_refinement_disabled = review_criteria_refinement_disabled

    @property
    def company_name(self):
        """Gets the company_name of this JobDetails.  # noqa: E501

        Name of the company under which the job is posted.  # noqa: E501

        :return: The company_name of this JobDetails.  # noqa: E501
        :rtype: str
        """
        return self._company_name

    @company_name.setter
    def company_name(self, company_name):
        """Sets the company_name of this JobDetails.

        Name of the company under which the job is posted.  # noqa: E501

        :param company_name: The company_name of this JobDetails.  # noqa: E501
        :type: str
        """

        self._company_name = company_name

    @property
    def language(self):
        """Gets the language of this JobDetails.  # noqa: E501

        Language of the job.  # noqa: E501

        :return: The language of this JobDetails.  # noqa: E501
        :rtype: str
        """
        return self._language

    @language.setter
    def language(self, language):
        """Sets the language of this JobDetails.

        Language of the job.  # noqa: E501

        :param language: The language of this JobDetails.  # noqa: E501
        :type: str
        """

        self._language = language

    @property
    def apply_count(self):
        """Gets the apply_count of this JobDetails.  # noqa: E501

        Number of candidates who have applied for the job.  # noqa: E501

        :return: The apply_count of this JobDetails.  # noqa: E501
        :rtype: float
        """
        return self._apply_count

    @apply_count.setter
    def apply_count(self, apply_count):
        """Sets the apply_count of this JobDetails.

        Number of candidates who have applied for the job.  # noqa: E501

        :param apply_count: The apply_count of this JobDetails.  # noqa: E501
        :type: float
        """

        self._apply_count = apply_count

    @property
    def job_requirements(self):
        """Gets the job_requirements of this JobDetails.  # noqa: E501

        Requirements of the job.  # noqa: E501

        :return: The job_requirements of this JobDetails.  # noqa: E501
        :rtype: str
        """
        return self._job_requirements

    @job_requirements.setter
    def job_requirements(self, job_requirements):
        """Sets the job_requirements of this JobDetails.

        Requirements of the job.  # noqa: E501

        :param job_requirements: The job_requirements of this JobDetails.  # noqa: E501
        :type: str
        """

        self._job_requirements = job_requirements

    @property
    def job_title(self):
        """Gets the job_title of this JobDetails.  # noqa: E501

        Title of the job.  # noqa: E501

        :return: The job_title of this JobDetails.  # noqa: E501
        :rtype: str
        """
        return self._job_title

    @job_title.setter
    def job_title(self, job_title):
        """Sets the job_title of this JobDetails.

        Title of the job.  # noqa: E501

        :param job_title: The job_title of this JobDetails.  # noqa: E501
        :type: str
        """

        self._job_title = job_title

    @property
    def job_code(self):
        """Gets the job_code of this JobDetails.  # noqa: E501

        Code of the job.  # noqa: E501

        :return: The job_code of this JobDetails.  # noqa: E501
        :rtype: str
        """
        return self._job_code

    @job_code.setter
    def job_code(self, job_code):
        """Sets the job_code of this JobDetails.

        Code of the job.  # noqa: E501

        :param job_code: The job_code of this JobDetails.  # noqa: E501
        :type: str
        """

        self._job_code = job_code

    @property
    def source(self):
        """Gets the source of this JobDetails.  # noqa: E501

        Tells the source of the job.  # noqa: E501

        :return: The source of this JobDetails.  # noqa: E501
        :rtype: str
        """
        return self._source

    @source.setter
    def source(self, source):
        """Sets the source of this JobDetails.

        Tells the source of the job.  # noqa: E501

        :param source: The source of this JobDetails.  # noqa: E501
        :type: str
        """
        allowed_values = ["HRM", "CRM", "WORKDAY"]  # noqa: E501
        if source not in allowed_values:
            raise ValueError(
                "Invalid value for `source` ({0}), must be one of {1}"  # noqa: E501
                .format(source, allowed_values)
            )

        self._source = source

    @property
    def updated_date(self):
        """Gets the updated_date of this JobDetails.  # noqa: E501

        Latest job updated date.  # noqa: E501

        :return: The updated_date of this JobDetails.  # noqa: E501
        :rtype: str
        """
        return self._updated_date

    @updated_date.setter
    def updated_date(self, updated_date):
        """Sets the updated_date of this JobDetails.

        Latest job updated date.  # noqa: E501

        :param updated_date: The updated_date of this JobDetails.  # noqa: E501
        :type: str
        """

        self._updated_date = updated_date

    @property
    def posted_date(self):
        """Gets the posted_date of this JobDetails.  # noqa: E501

        Job posted date.  # noqa: E501

        :return: The posted_date of this JobDetails.  # noqa: E501
        :rtype: str
        """
        return self._posted_date

    @posted_date.setter
    def posted_date(self, posted_date):
        """Sets the posted_date of this JobDetails.

        Job posted date.  # noqa: E501

        :param posted_date: The posted_date of this JobDetails.  # noqa: E501
        :type: str
        """

        self._posted_date = posted_date

    @property
    def is_ever_green_req(self):
        """Gets the is_ever_green_req of this JobDetails.  # noqa: E501

        Indicates if the job is an evergreen requisition.  # noqa: E501

        :return: The is_ever_green_req of this JobDetails.  # noqa: E501
        :rtype: str
        """
        return self._is_ever_green_req

    @is_ever_green_req.setter
    def is_ever_green_req(self, is_ever_green_req):
        """Sets the is_ever_green_req of this JobDetails.

        Indicates if the job is an evergreen requisition.  # noqa: E501

        :param is_ever_green_req: The is_ever_green_req of this JobDetails.  # noqa: E501
        :type: str
        """

        self._is_ever_green_req = is_ever_green_req

    @property
    def job_family(self):
        """Gets the job_family of this JobDetails.  # noqa: E501

        Family to which the job belongs.  # noqa: E501

        :return: The job_family of this JobDetails.  # noqa: E501
        :rtype: str
        """
        return self._job_family

    @job_family.setter
    def job_family(self, job_family):
        """Sets the job_family of this JobDetails.

        Family to which the job belongs.  # noqa: E501

        :param job_family: The job_family of this JobDetails.  # noqa: E501
        :type: str
        """

        self._job_family = job_family

    @property
    def agency_list(self):
        """Gets the agency_list of this JobDetails.  # noqa: E501

        List of agencies associated with the job.  # noqa: E501

        :return: The agency_list of this JobDetails.  # noqa: E501
        :rtype: list[object]
        """
        return self._agency_list

    @agency_list.setter
    def agency_list(self, agency_list):
        """Sets the agency_list of this JobDetails.

        List of agencies associated with the job.  # noqa: E501

        :param agency_list: The agency_list of this JobDetails.  # noqa: E501
        :type: list[object]
        """

        self._agency_list = agency_list

    @property
    def ats(self):
        """Gets the ats of this JobDetails.  # noqa: E501

        Applicant Tracking System identifier.  # noqa: E501

        :return: The ats of this JobDetails.  # noqa: E501
        :rtype: str
        """
        return self._ats

    @ats.setter
    def ats(self, ats):
        """Sets the ats of this JobDetails.

        Applicant Tracking System identifier.  # noqa: E501

        :param ats: The ats of this JobDetails.  # noqa: E501
        :type: str
        """

        self._ats = ats

    @property
    def preferred_languages(self):
        """Gets the preferred_languages of this JobDetails.  # noqa: E501

        Preferred languages for the job.  # noqa: E501

        :return: The preferred_languages of this JobDetails.  # noqa: E501
        :rtype: list[object]
        """
        return self._preferred_languages

    @preferred_languages.setter
    def preferred_languages(self, preferred_languages):
        """Sets the preferred_languages of this JobDetails.

        Preferred languages for the job.  # noqa: E501

        :param preferred_languages: The preferred_languages of this JobDetails.  # noqa: E501
        :type: list[object]
        """

        self._preferred_languages = preferred_languages

    @property
    def posted_by(self):
        """Gets the posted_by of this JobDetails.  # noqa: E501


        :return: The posted_by of this JobDetails.  # noqa: E501
        :rtype: JobDetailsPostedBy
        """
        return self._posted_by

    @posted_by.setter
    def posted_by(self, posted_by):
        """Sets the posted_by of this JobDetails.


        :param posted_by: The posted_by of this JobDetails.  # noqa: E501
        :type: JobDetailsPostedBy
        """

        self._posted_by = posted_by

    @property
    def posting_status(self):
        """Gets the posting_status of this JobDetails.  # noqa: E501

        Status of the job posting.  # noqa: E501

        :return: The posting_status of this JobDetails.  # noqa: E501
        :rtype: str
        """
        return self._posting_status

    @posting_status.setter
    def posting_status(self, posting_status):
        """Sets the posting_status of this JobDetails.

        Status of the job posting.  # noqa: E501

        :param posting_status: The posting_status of this JobDetails.  # noqa: E501
        :type: str
        """

        self._posting_status = posting_status

    @property
    def fit_score_meta_data(self):
        """Gets the fit_score_meta_data of this JobDetails.  # noqa: E501


        :return: The fit_score_meta_data of this JobDetails.  # noqa: E501
        :rtype: JobDetailsFitScoreMetaData
        """
        return self._fit_score_meta_data

    @fit_score_meta_data.setter
    def fit_score_meta_data(self, fit_score_meta_data):
        """Sets the fit_score_meta_data of this JobDetails.


        :param fit_score_meta_data: The fit_score_meta_data of this JobDetails.  # noqa: E501
        :type: JobDetailsFitScoreMetaData
        """

        self._fit_score_meta_data = fit_score_meta_data

    @property
    def relation_type(self):
        """Gets the relation_type of this JobDetails.  # noqa: E501


        :return: The relation_type of this JobDetails.  # noqa: E501
        :rtype: JobDetailsRelationType
        """
        return self._relation_type

    @relation_type.setter
    def relation_type(self, relation_type):
        """Sets the relation_type of this JobDetails.


        :param relation_type: The relation_type of this JobDetails.  # noqa: E501
        :type: JobDetailsRelationType
        """

        self._relation_type = relation_type

    @property
    def description_teaser(self):
        """Gets the description_teaser of this JobDetails.  # noqa: E501

        Teaser text related to the job description.  # noqa: E501

        :return: The description_teaser of this JobDetails.  # noqa: E501
        :rtype: str
        """
        return self._description_teaser

    @description_teaser.setter
    def description_teaser(self, description_teaser):
        """Sets the description_teaser of this JobDetails.

        Teaser text related to the job description.  # noqa: E501

        :param description_teaser: The description_teaser of this JobDetails.  # noqa: E501
        :type: str
        """

        self._description_teaser = description_teaser

    @property
    def description(self):
        """Gets the description of this JobDetails.  # noqa: E501

        Job's description.  # noqa: E501

        :return: The description of this JobDetails.  # noqa: E501
        :rtype: str
        """
        return self._description

    @description.setter
    def description(self, description):
        """Sets the description of this JobDetails.

        Job's description.  # noqa: E501

        :param description: The description of this JobDetails.  # noqa: E501
        :type: str
        """

        self._description = description

    @property
    def job_url_map(self):
        """Gets the job_url_map of this JobDetails.  # noqa: E501

        Mapping of URLs associated with the job.  # noqa: E501

        :return: The job_url_map of this JobDetails.  # noqa: E501
        :rtype: object
        """
        return self._job_url_map

    @job_url_map.setter
    def job_url_map(self, job_url_map):
        """Sets the job_url_map of this JobDetails.

        Mapping of URLs associated with the job.  # noqa: E501

        :param job_url_map: The job_url_map of this JobDetails.  # noqa: E501
        :type: object
        """

        self._job_url_map = job_url_map

    @property
    def visibility_type(self):
        """Gets the visibility_type of this JobDetails.  # noqa: E501

        Visibility type of the job.  # noqa: E501

        :return: The visibility_type of this JobDetails.  # noqa: E501
        :rtype: str
        """
        return self._visibility_type

    @visibility_type.setter
    def visibility_type(self, visibility_type):
        """Sets the visibility_type of this JobDetails.

        Visibility type of the job.  # noqa: E501

        :param visibility_type: The visibility_type of this JobDetails.  # noqa: E501
        :type: str
        """

        self._visibility_type = visibility_type

    @property
    def site_type(self):
        """Gets the site_type of this JobDetails.  # noqa: E501

        Type of site associated with the job.  # noqa: E501

        :return: The site_type of this JobDetails.  # noqa: E501
        :rtype: str
        """
        return self._site_type

    @site_type.setter
    def site_type(self, site_type):
        """Sets the site_type of this JobDetails.

        Type of site associated with the job.  # noqa: E501

        :param site_type: The site_type of this JobDetails.  # noqa: E501
        :type: str
        """

        self._site_type = site_type

    @property
    def is_private(self):
        """Gets the is_private of this JobDetails.  # noqa: E501

        Whether the job is private (true or false).  # noqa: E501

        :return: The is_private of this JobDetails.  # noqa: E501
        :rtype: bool
        """
        return self._is_private

    @is_private.setter
    def is_private(self, is_private):
        """Sets the is_private of this JobDetails.

        Whether the job is private (true or false).  # noqa: E501

        :param is_private: The is_private of this JobDetails.  # noqa: E501
        :type: bool
        """

        self._is_private = is_private

    @property
    def internal_category_id(self):
        """Gets the internal_category_id of this JobDetails.  # noqa: E501

        Internal category ID.  # noqa: E501

        :return: The internal_category_id of this JobDetails.  # noqa: E501
        :rtype: str
        """
        return self._internal_category_id

    @internal_category_id.setter
    def internal_category_id(self, internal_category_id):
        """Sets the internal_category_id of this JobDetails.

        Internal category ID.  # noqa: E501

        :param internal_category_id: The internal_category_id of this JobDetails.  # noqa: E501
        :type: str
        """

        self._internal_category_id = internal_category_id

    @property
    def language_code(self):
        """Gets the language_code of this JobDetails.  # noqa: E501

        Language code.  # noqa: E501

        :return: The language_code of this JobDetails.  # noqa: E501
        :rtype: str
        """
        return self._language_code

    @language_code.setter
    def language_code(self, language_code):
        """Sets the language_code of this JobDetails.

        Language code.  # noqa: E501

        :param language_code: The language_code of this JobDetails.  # noqa: E501
        :type: str
        """

        self._language_code = language_code

    @property
    def hiring_manager(self):
        """Gets the hiring_manager of this JobDetails.  # noqa: E501


        :return: The hiring_manager of this JobDetails.  # noqa: E501
        :rtype: JobDetailsHiringManager
        """
        return self._hiring_manager

    @hiring_manager.setter
    def hiring_manager(self, hiring_manager):
        """Sets the hiring_manager of this JobDetails.


        :param hiring_manager: The hiring_manager of this JobDetails.  # noqa: E501
        :type: JobDetailsHiringManager
        """

        self._hiring_manager = hiring_manager

    @property
    def multi_category(self):
        """Gets the multi_category of this JobDetails.  # noqa: E501

        List of categories associated with the job.  # noqa: E501

        :return: The multi_category of this JobDetails.  # noqa: E501
        :rtype: list[JobDetailsMultiCategory]
        """
        return self._multi_category

    @multi_category.setter
    def multi_category(self, multi_category):
        """Sets the multi_category of this JobDetails.

        List of categories associated with the job.  # noqa: E501

        :param multi_category: The multi_category of this JobDetails.  # noqa: E501
        :type: list[JobDetailsMultiCategory]
        """

        self._multi_category = multi_category

    @property
    def publish_to(self):
        """Gets the publish_to of this JobDetails.  # noqa: E501

        Details of where the job is published.  # noqa: E501

        :return: The publish_to of this JobDetails.  # noqa: E501
        :rtype: list[JobDetailsPublishTo]
        """
        return self._publish_to

    @publish_to.setter
    def publish_to(self, publish_to):
        """Sets the publish_to of this JobDetails.

        Details of where the job is published.  # noqa: E501

        :param publish_to: The publish_to of this JobDetails.  # noqa: E501
        :type: list[JobDetailsPublishTo]
        """

        self._publish_to = publish_to

    @property
    def locale(self):
        """Gets the locale of this JobDetails.  # noqa: E501

        Default language of the job.  # noqa: E501

        :return: The locale of this JobDetails.  # noqa: E501
        :rtype: str
        """
        return self._locale

    @locale.setter
    def locale(self, locale):
        """Sets the locale of this JobDetails.

        Default language of the job.  # noqa: E501

        :param locale: The locale of this JobDetails.  # noqa: E501
        :type: str
        """

        self._locale = locale

    @property
    def display_career_site(self):
        """Gets the display_career_site of this JobDetails.  # noqa: E501

        Display career site (true or false).  # noqa: E501

        :return: The display_career_site of this JobDetails.  # noqa: E501
        :rtype: bool
        """
        return self._display_career_site

    @display_career_site.setter
    def display_career_site(self, display_career_site):
        """Sets the display_career_site of this JobDetails.

        Display career site (true or false).  # noqa: E501

        :param display_career_site: The display_career_site of this JobDetails.  # noqa: E501
        :type: bool
        """

        self._display_career_site = display_career_site

    @property
    def assigned(self):
        """Gets the assigned of this JobDetails.  # noqa: E501

        Details of users assigned to the job.  # noqa: E501

        :return: The assigned of this JobDetails.  # noqa: E501
        :rtype: list[JobDetailsAssigned]
        """
        return self._assigned

    @assigned.setter
    def assigned(self, assigned):
        """Sets the assigned of this JobDetails.

        Details of users assigned to the job.  # noqa: E501

        :param assigned: The assigned of this JobDetails.  # noqa: E501
        :type: list[JobDetailsAssigned]
        """

        self._assigned = assigned

    @property
    def job_zone(self):
        """Gets the job_zone of this JobDetails.  # noqa: E501

        Job zone.  # noqa: E501

        :return: The job_zone of this JobDetails.  # noqa: E501
        :rtype: str
        """
        return self._job_zone

    @job_zone.setter
    def job_zone(self, job_zone):
        """Sets the job_zone of this JobDetails.

        Job zone.  # noqa: E501

        :param job_zone: The job_zone of this JobDetails.  # noqa: E501
        :type: str
        """

        self._job_zone = job_zone

    @property
    def multi_location(self):
        """Gets the multi_location of this JobDetails.  # noqa: E501

        Details of multiple locations associated with the job.  # noqa: E501

        :return: The multi_location of this JobDetails.  # noqa: E501
        :rtype: list[JobDetailsMultiLocation]
        """
        return self._multi_location

    @multi_location.setter
    def multi_location(self, multi_location):
        """Sets the multi_location of this JobDetails.

        Details of multiple locations associated with the job.  # noqa: E501

        :param multi_location: The multi_location of this JobDetails.  # noqa: E501
        :type: list[JobDetailsMultiLocation]
        """

        self._multi_location = multi_location

    @property
    def job_merge_score(self):
        """Gets the job_merge_score of this JobDetails.  # noqa: E501

        Merge score of the job.  # noqa: E501

        :return: The job_merge_score of this JobDetails.  # noqa: E501
        :rtype: float
        """
        return self._job_merge_score

    @job_merge_score.setter
    def job_merge_score(self, job_merge_score):
        """Sets the job_merge_score of this JobDetails.

        Merge score of the job.  # noqa: E501

        :param job_merge_score: The job_merge_score of this JobDetails.  # noqa: E501
        :type: float
        """

        self._job_merge_score = job_merge_score

    @property
    def benefits(self):
        """Gets the benefits of this JobDetails.  # noqa: E501

        Benefits associated with the job.  # noqa: E501

        :return: The benefits of this JobDetails.  # noqa: E501
        :rtype: str
        """
        return self._benefits

    @benefits.setter
    def benefits(self, benefits):
        """Sets the benefits of this JobDetails.

        Benefits associated with the job.  # noqa: E501

        :param benefits: The benefits of this JobDetails.  # noqa: E501
        :type: str
        """

        self._benefits = benefits

    @property
    def job_id(self):
        """Gets the job_id of this JobDetails.  # noqa: E501

        Job's reference ID.  # noqa: E501

        :return: The job_id of this JobDetails.  # noqa: E501
        :rtype: str
        """
        return self._job_id

    @job_id.setter
    def job_id(self, job_id):
        """Sets the job_id of this JobDetails.

        Job's reference ID.  # noqa: E501

        :param job_id: The job_id of this JobDetails.  # noqa: E501
        :type: str
        """

        self._job_id = job_id

    @property
    def job_category(self):
        """Gets the job_category of this JobDetails.  # noqa: E501

        Job's category.  # noqa: E501

        :return: The job_category of this JobDetails.  # noqa: E501
        :rtype: str
        """
        return self._job_category

    @job_category.setter
    def job_category(self, job_category):
        """Sets the job_category of this JobDetails.

        Job's category.  # noqa: E501

        :param job_category: The job_category of this JobDetails.  # noqa: E501
        :type: str
        """

        self._job_category = job_category

    @property
    def job_experience(self):
        """Gets the job_experience of this JobDetails.  # noqa: E501

        Job's experience.  # noqa: E501

        :return: The job_experience of this JobDetails.  # noqa: E501
        :rtype: str
        """
        return self._job_experience

    @job_experience.setter
    def job_experience(self, job_experience):
        """Sets the job_experience of this JobDetails.

        Job's experience.  # noqa: E501

        :param job_experience: The job_experience of this JobDetails.  # noqa: E501
        :type: str
        """

        self._job_experience = job_experience

    @property
    def status(self):
        """Gets the status of this JobDetails.  # noqa: E501

        Job's status whether it's open, closed, or in draft.  # noqa: E501

        :return: The status of this JobDetails.  # noqa: E501
        :rtype: str
        """
        return self._status

    @status.setter
    def status(self, status):
        """Sets the status of this JobDetails.

        Job's status whether it's open, closed, or in draft.  # noqa: E501

        :param status: The status of this JobDetails.  # noqa: E501
        :type: str
        """
        allowed_values = ["open", "close", "draft"]  # noqa: E501
        if status not in allowed_values:
            raise ValueError(
                "Invalid value for `status` ({0}), must be one of {1}"  # noqa: E501
                .format(status, allowed_values)
            )

        self._status = status

    @property
    def tenant_specific_additional_fields(self):
        """Gets the tenant_specific_additional_fields of this JobDetails.  # noqa: E501

        Additional fields specific to the tenant associated with the job.  # noqa: E501

        :return: The tenant_specific_additional_fields of this JobDetails.  # noqa: E501
        :rtype: list[JobDetailsTenantSpecificAdditionalFields]
        """
        return self._tenant_specific_additional_fields

    @tenant_specific_additional_fields.setter
    def tenant_specific_additional_fields(self, tenant_specific_additional_fields):
        """Sets the tenant_specific_additional_fields of this JobDetails.

        Additional fields specific to the tenant associated with the job.  # noqa: E501

        :param tenant_specific_additional_fields: The tenant_specific_additional_fields of this JobDetails.  # noqa: E501
        :type: list[JobDetailsTenantSpecificAdditionalFields]
        """

        self._tenant_specific_additional_fields = tenant_specific_additional_fields

    @property
    def visibility_locale(self):
        """Gets the visibility_locale of this JobDetails.  # noqa: E501

        List of locales where the job is visible.  # noqa: E501

        :return: The visibility_locale of this JobDetails.  # noqa: E501
        :rtype: list[str]
        """
        return self._visibility_locale

    @visibility_locale.setter
    def visibility_locale(self, visibility_locale):
        """Sets the visibility_locale of this JobDetails.

        List of locales where the job is visible.  # noqa: E501

        :param visibility_locale: The visibility_locale of this JobDetails.  # noqa: E501
        :type: list[str]
        """

        self._visibility_locale = visibility_locale

    @property
    def default(self):
        """Gets the default of this JobDetails.  # noqa: E501

        Is a default job (true or false).  # noqa: E501

        :return: The default of this JobDetails.  # noqa: E501
        :rtype: bool
        """
        return self._default

    @default.setter
    def default(self, default):
        """Sets the default of this JobDetails.

        Is a default job (true or false).  # noqa: E501

        :param default: The default of this JobDetails.  # noqa: E501
        :type: bool
        """

        self._default = default

    @property
    def is_deleted(self):
        """Gets the is_deleted of this JobDetails.  # noqa: E501

        Is a deleted job (true or false).  # noqa: E501

        :return: The is_deleted of this JobDetails.  # noqa: E501
        :rtype: bool
        """
        return self._is_deleted

    @is_deleted.setter
    def is_deleted(self, is_deleted):
        """Sets the is_deleted of this JobDetails.

        Is a deleted job (true or false).  # noqa: E501

        :param is_deleted: The is_deleted of this JobDetails.  # noqa: E501
        :type: bool
        """

        self._is_deleted = is_deleted

    @property
    def country_code(self):
        """Gets the country_code of this JobDetails.  # noqa: E501

        Country code in which the job is posted.  # noqa: E501

        :return: The country_code of this JobDetails.  # noqa: E501
        :rtype: str
        """
        return self._country_code

    @country_code.setter
    def country_code(self, country_code):
        """Sets the country_code of this JobDetails.

        Country code in which the job is posted.  # noqa: E501

        :param country_code: The country_code of this JobDetails.  # noqa: E501
        :type: str
        """

        self._country_code = country_code

    @property
    def candidates_in_process(self):
        """Gets the candidates_in_process of this JobDetails.  # noqa: E501

        Number of candidates in process for this job.  # noqa: E501

        :return: The candidates_in_process of this JobDetails.  # noqa: E501
        :rtype: float
        """
        return self._candidates_in_process

    @candidates_in_process.setter
    def candidates_in_process(self, candidates_in_process):
        """Sets the candidates_in_process of this JobDetails.

        Number of candidates in process for this job.  # noqa: E501

        :param candidates_in_process: The candidates_in_process of this JobDetails.  # noqa: E501
        :type: float
        """

        self._candidates_in_process = candidates_in_process

    @property
    def candidates_to_be_evaluated(self):
        """Gets the candidates_to_be_evaluated of this JobDetails.  # noqa: E501

        Number of candidates to be evaluated in this job.  # noqa: E501

        :return: The candidates_to_be_evaluated of this JobDetails.  # noqa: E501
        :rtype: float
        """
        return self._candidates_to_be_evaluated

    @candidates_to_be_evaluated.setter
    def candidates_to_be_evaluated(self, candidates_to_be_evaluated):
        """Sets the candidates_to_be_evaluated of this JobDetails.

        Number of candidates to be evaluated in this job.  # noqa: E501

        :param candidates_to_be_evaluated: The candidates_to_be_evaluated of this JobDetails.  # noqa: E501
        :type: float
        """

        self._candidates_to_be_evaluated = candidates_to_be_evaluated

    @property
    def candidates_to_be_offered(self):
        """Gets the candidates_to_be_offered of this JobDetails.  # noqa: E501

        Number of candidates to make offers in this job.  # noqa: E501

        :return: The candidates_to_be_offered of this JobDetails.  # noqa: E501
        :rtype: float
        """
        return self._candidates_to_be_offered

    @candidates_to_be_offered.setter
    def candidates_to_be_offered(self, candidates_to_be_offered):
        """Sets the candidates_to_be_offered of this JobDetails.

        Number of candidates to make offers in this job.  # noqa: E501

        :param candidates_to_be_offered: The candidates_to_be_offered of this JobDetails.  # noqa: E501
        :type: float
        """

        self._candidates_to_be_offered = candidates_to_be_offered

    @property
    def candidates_reviewed(self):
        """Gets the candidates_reviewed of this JobDetails.  # noqa: E501

        Number of candidates reviewed in this job.  # noqa: E501

        :return: The candidates_reviewed of this JobDetails.  # noqa: E501
        :rtype: float
        """
        return self._candidates_reviewed

    @candidates_reviewed.setter
    def candidates_reviewed(self, candidates_reviewed):
        """Sets the candidates_reviewed of this JobDetails.

        Number of candidates reviewed in this job.  # noqa: E501

        :param candidates_reviewed: The candidates_reviewed of this JobDetails.  # noqa: E501
        :type: float
        """

        self._candidates_reviewed = candidates_reviewed

    @property
    def pending_candidates(self):
        """Gets the pending_candidates of this JobDetails.  # noqa: E501

        Number of pending candidates on whom an action needs to be taken in this job.  # noqa: E501

        :return: The pending_candidates of this JobDetails.  # noqa: E501
        :rtype: float
        """
        return self._pending_candidates

    @pending_candidates.setter
    def pending_candidates(self, pending_candidates):
        """Sets the pending_candidates of this JobDetails.

        Number of pending candidates on whom an action needs to be taken in this job.  # noqa: E501

        :param pending_candidates: The pending_candidates of this JobDetails.  # noqa: E501
        :type: float
        """

        self._pending_candidates = pending_candidates

    @property
    def candidates_evaluated(self):
        """Gets the candidates_evaluated of this JobDetails.  # noqa: E501

        Number of candidates evaluated in this job.  # noqa: E501

        :return: The candidates_evaluated of this JobDetails.  # noqa: E501
        :rtype: float
        """
        return self._candidates_evaluated

    @candidates_evaluated.setter
    def candidates_evaluated(self, candidates_evaluated):
        """Sets the candidates_evaluated of this JobDetails.

        Number of candidates evaluated in this job.  # noqa: E501

        :param candidates_evaluated: The candidates_evaluated of this JobDetails.  # noqa: E501
        :type: float
        """

        self._candidates_evaluated = candidates_evaluated

    @property
    def number_of_candidates(self):
        """Gets the number_of_candidates of this JobDetails.  # noqa: E501

        Number of candidates in the job.  # noqa: E501

        :return: The number_of_candidates of this JobDetails.  # noqa: E501
        :rtype: float
        """
        return self._number_of_candidates

    @number_of_candidates.setter
    def number_of_candidates(self, number_of_candidates):
        """Sets the number_of_candidates of this JobDetails.

        Number of candidates in the job.  # noqa: E501

        :param number_of_candidates: The number_of_candidates of this JobDetails.  # noqa: E501
        :type: float
        """

        self._number_of_candidates = number_of_candidates

    @property
    def interview_scheduled_count(self):
        """Gets the interview_scheduled_count of this JobDetails.  # noqa: E501

        Number of interviews scheduled for this job.  # noqa: E501

        :return: The interview_scheduled_count of this JobDetails.  # noqa: E501
        :rtype: float
        """
        return self._interview_scheduled_count

    @interview_scheduled_count.setter
    def interview_scheduled_count(self, interview_scheduled_count):
        """Sets the interview_scheduled_count of this JobDetails.

        Number of interviews scheduled for this job.  # noqa: E501

        :param interview_scheduled_count: The interview_scheduled_count of this JobDetails.  # noqa: E501
        :type: float
        """

        self._interview_scheduled_count = interview_scheduled_count

    @property
    def candidates_to_be_reviewed(self):
        """Gets the candidates_to_be_reviewed of this JobDetails.  # noqa: E501

        Number of candidates to be reviewed.  # noqa: E501

        :return: The candidates_to_be_reviewed of this JobDetails.  # noqa: E501
        :rtype: float
        """
        return self._candidates_to_be_reviewed

    @candidates_to_be_reviewed.setter
    def candidates_to_be_reviewed(self, candidates_to_be_reviewed):
        """Sets the candidates_to_be_reviewed of this JobDetails.

        Number of candidates to be reviewed.  # noqa: E501

        :param candidates_to_be_reviewed: The candidates_to_be_reviewed of this JobDetails.  # noqa: E501
        :type: float
        """

        self._candidates_to_be_reviewed = candidates_to_be_reviewed

    @property
    def user_role(self):
        """Gets the user_role of this JobDetails.  # noqa: E501

        User's role related to this job.  # noqa: E501

        :return: The user_role of this JobDetails.  # noqa: E501
        :rtype: str
        """
        return self._user_role

    @user_role.setter
    def user_role(self, user_role):
        """Sets the user_role of this JobDetails.

        User's role related to this job.  # noqa: E501

        :param user_role: The user_role of this JobDetails.  # noqa: E501
        :type: str
        """

        self._user_role = user_role

    @property
    def company(self):
        """Gets the company of this JobDetails.  # noqa: E501

        The company name.  # noqa: E501

        :return: The company of this JobDetails.  # noqa: E501
        :rtype: str
        """
        return self._company

    @company.setter
    def company(self, company):
        """Sets the company of this JobDetails.

        The company name.  # noqa: E501

        :param company: The company of this JobDetails.  # noqa: E501
        :type: str
        """

        self._company = company

    @property
    def hashkey(self):
        """Gets the hashkey of this JobDetails.  # noqa: E501

        The hash key.  # noqa: E501

        :return: The hashkey of this JobDetails.  # noqa: E501
        :rtype: str
        """
        return self._hashkey

    @hashkey.setter
    def hashkey(self, hashkey):
        """Sets the hashkey of this JobDetails.

        The hash key.  # noqa: E501

        :param hashkey: The hashkey of this JobDetails.  # noqa: E501
        :type: str
        """

        self._hashkey = hashkey

    @property
    def apply_url(self):
        """Gets the apply_url of this JobDetails.  # noqa: E501

        URL to apply for this job.  # noqa: E501

        :return: The apply_url of this JobDetails.  # noqa: E501
        :rtype: str
        """
        return self._apply_url

    @apply_url.setter
    def apply_url(self, apply_url):
        """Sets the apply_url of this JobDetails.

        URL to apply for this job.  # noqa: E501

        :param apply_url: The apply_url of this JobDetails.  # noqa: E501
        :type: str
        """

        self._apply_url = apply_url

    @property
    def onet(self):
        """Gets the onet of this JobDetails.  # noqa: E501

        Details related to O*NET (Occupational Information Network) codes for the job.  # noqa: E501

        :return: The onet of this JobDetails.  # noqa: E501
        :rtype: list[JobDetailsOnet]
        """
        return self._onet

    @onet.setter
    def onet(self, onet):
        """Sets the onet of this JobDetails.

        Details related to O*NET (Occupational Information Network) codes for the job.  # noqa: E501

        :param onet: The onet of this JobDetails.  # noqa: E501
        :type: list[JobDetailsOnet]
        """

        self._onet = onet

    @property
    def variations(self):
        """Gets the variations of this JobDetails.  # noqa: E501

        Variations or versions of the job based on different criteria.  # noqa: E501

        :return: The variations of this JobDetails.  # noqa: E501
        :rtype: list[JobDetailsVariations]
        """
        return self._variations

    @variations.setter
    def variations(self, variations):
        """Sets the variations of this JobDetails.

        Variations or versions of the job based on different criteria.  # noqa: E501

        :param variations: The variations of this JobDetails.  # noqa: E501
        :type: list[JobDetailsVariations]
        """

        self._variations = variations

    @property
    def hiring_team_list(self):
        """Gets the hiring_team_list of this JobDetails.  # noqa: E501

        List of team members associated with the job.  # noqa: E501

        :return: The hiring_team_list of this JobDetails.  # noqa: E501
        :rtype: list[JobDetailsHiringTeamList]
        """
        return self._hiring_team_list

    @hiring_team_list.setter
    def hiring_team_list(self, hiring_team_list):
        """Sets the hiring_team_list of this JobDetails.

        List of team members associated with the job.  # noqa: E501

        :param hiring_team_list: The hiring_team_list of this JobDetails.  # noqa: E501
        :type: list[JobDetailsHiringTeamList]
        """

        self._hiring_team_list = hiring_team_list

    @property
    def department(self):
        """Gets the department of this JobDetails.  # noqa: E501

        Department to which the job belongs.  # noqa: E501

        :return: The department of this JobDetails.  # noqa: E501
        :rtype: str
        """
        return self._department

    @department.setter
    def department(self, department):
        """Sets the department of this JobDetails.

        Department to which the job belongs.  # noqa: E501

        :param department: The department of this JobDetails.  # noqa: E501
        :type: str
        """

        self._department = department

    @property
    def job_type(self):
        """Gets the job_type of this JobDetails.  # noqa: E501

        Job type, whether part-time or full-time.  # noqa: E501

        :return: The job_type of this JobDetails.  # noqa: E501
        :rtype: str
        """
        return self._job_type

    @job_type.setter
    def job_type(self, job_type):
        """Sets the job_type of this JobDetails.

        Job type, whether part-time or full-time.  # noqa: E501

        :param job_type: The job_type of this JobDetails.  # noqa: E501
        :type: str
        """

        self._job_type = job_type

    @property
    def visibility_site_type(self):
        """Gets the visibility_site_type of this JobDetails.  # noqa: E501

        List of site types where the job is visible.  # noqa: E501

        :return: The visibility_site_type of this JobDetails.  # noqa: E501
        :rtype: list[str]
        """
        return self._visibility_site_type

    @visibility_site_type.setter
    def visibility_site_type(self, visibility_site_type):
        """Sets the visibility_site_type of this JobDetails.

        List of site types where the job is visible.  # noqa: E501

        :param visibility_site_type: The visibility_site_type of this JobDetails.  # noqa: E501
        :type: list[str]
        """

        self._visibility_site_type = visibility_site_type

    @property
    def is_confidential(self):
        """Gets the is_confidential of this JobDetails.  # noqa: E501

        Is a confidential job (true or false).  # noqa: E501

        :return: The is_confidential of this JobDetails.  # noqa: E501
        :rtype: bool
        """
        return self._is_confidential

    @is_confidential.setter
    def is_confidential(self, is_confidential):
        """Sets the is_confidential of this JobDetails.

        Is a confidential job (true or false).  # noqa: E501

        :param is_confidential: The is_confidential of this JobDetails.  # noqa: E501
        :type: bool
        """

        self._is_confidential = is_confidential

    @property
    def skills_and_experience(self):
        """Gets the skills_and_experience of this JobDetails.  # noqa: E501

        Skills and experiences required for the job.  # noqa: E501

        :return: The skills_and_experience of this JobDetails.  # noqa: E501
        :rtype: str
        """
        return self._skills_and_experience

    @skills_and_experience.setter
    def skills_and_experience(self, skills_and_experience):
        """Sets the skills_and_experience of this JobDetails.

        Skills and experiences required for the job.  # noqa: E501

        :param skills_and_experience: The skills_and_experience of this JobDetails.  # noqa: E501
        :type: str
        """

        self._skills_and_experience = skills_and_experience

    @property
    def scrape_time(self):
        """Gets the scrape_time of this JobDetails.  # noqa: E501

        Time took to scrape the job.  # noqa: E501

        :return: The scrape_time of this JobDetails.  # noqa: E501
        :rtype: str
        """
        return self._scrape_time

    @scrape_time.setter
    def scrape_time(self, scrape_time):
        """Sets the scrape_time of this JobDetails.

        Time took to scrape the job.  # noqa: E501

        :param scrape_time: The scrape_time of this JobDetails.  # noqa: E501
        :type: str
        """

        self._scrape_time = scrape_time

    @property
    def created_date(self):
        """Gets the created_date of this JobDetails.  # noqa: E501

        Job creation date.  # noqa: E501

        :return: The created_date of this JobDetails.  # noqa: E501
        :rtype: str
        """
        return self._created_date

    @created_date.setter
    def created_date(self, created_date):
        """Sets the created_date of this JobDetails.

        Job creation date.  # noqa: E501

        :param created_date: The created_date of this JobDetails.  # noqa: E501
        :type: str
        """

        self._created_date = created_date

    @property
    def job_visibility(self):
        """Gets the job_visibility of this JobDetails.  # noqa: E501

        Job's visibility.  # noqa: E501

        :return: The job_visibility of this JobDetails.  # noqa: E501
        :rtype: str
        """
        return self._job_visibility

    @job_visibility.setter
    def job_visibility(self, job_visibility):
        """Sets the job_visibility of this JobDetails.

        Job's visibility.  # noqa: E501

        :param job_visibility: The job_visibility of this JobDetails.  # noqa: E501
        :type: str
        """

        self._job_visibility = job_visibility

    @property
    def job_location(self):
        """Gets the job_location of this JobDetails.  # noqa: E501

        Job's location.  # noqa: E501

        :return: The job_location of this JobDetails.  # noqa: E501
        :rtype: str
        """
        return self._job_location

    @job_location.setter
    def job_location(self, job_location):
        """Sets the job_location of this JobDetails.

        Job's location.  # noqa: E501

        :param job_location: The job_location of this JobDetails.  # noqa: E501
        :type: str
        """

        self._job_location = job_location

    @property
    def publish(self):
        """Gets the publish of this JobDetails.  # noqa: E501

        Indicates if the job is published.  # noqa: E501

        :return: The publish of this JobDetails.  # noqa: E501
        :rtype: bool
        """
        return self._publish

    @publish.setter
    def publish(self, publish):
        """Sets the publish of this JobDetails.

        Indicates if the job is published.  # noqa: E501

        :param publish: The publish of this JobDetails.  # noqa: E501
        :type: bool
        """

        self._publish = publish

    @property
    def is_critical(self):
        """Gets the is_critical of this JobDetails.  # noqa: E501

        Is a critical job (true or false).  # noqa: E501

        :return: The is_critical of this JobDetails.  # noqa: E501
        :rtype: bool
        """
        return self._is_critical

    @is_critical.setter
    def is_critical(self, is_critical):
        """Sets the is_critical of this JobDetails.

        Is a critical job (true or false).  # noqa: E501

        :param is_critical: The is_critical of this JobDetails.  # noqa: E501
        :type: bool
        """

        self._is_critical = is_critical

    @property
    def hiring_manager_list(self):
        """Gets the hiring_manager_list of this JobDetails.  # noqa: E501

        List of hiring managers associated with the job.  # noqa: E501

        :return: The hiring_manager_list of this JobDetails.  # noqa: E501
        :rtype: list[JobDetailsHiringManagerList]
        """
        return self._hiring_manager_list

    @hiring_manager_list.setter
    def hiring_manager_list(self, hiring_manager_list):
        """Sets the hiring_manager_list of this JobDetails.

        List of hiring managers associated with the job.  # noqa: E501

        :param hiring_manager_list: The hiring_manager_list of this JobDetails.  # noqa: E501
        :type: list[JobDetailsHiringManagerList]
        """

        self._hiring_manager_list = hiring_manager_list

    @property
    def candidates_video_evaluated(self):
        """Gets the candidates_video_evaluated of this JobDetails.  # noqa: E501

        Number of candidates to evaluate video interviews.  # noqa: E501

        :return: The candidates_video_evaluated of this JobDetails.  # noqa: E501
        :rtype: float
        """
        return self._candidates_video_evaluated

    @candidates_video_evaluated.setter
    def candidates_video_evaluated(self, candidates_video_evaluated):
        """Sets the candidates_video_evaluated of this JobDetails.

        Number of candidates to evaluate video interviews.  # noqa: E501

        :param candidates_video_evaluated: The candidates_video_evaluated of this JobDetails.  # noqa: E501
        :type: float
        """

        self._candidates_video_evaluated = candidates_video_evaluated

    @property
    def candidates_to_be_video_evaluated(self):
        """Gets the candidates_to_be_video_evaluated of this JobDetails.  # noqa: E501

        Number of candidates whose video evaluation is done.  # noqa: E501

        :return: The candidates_to_be_video_evaluated of this JobDetails.  # noqa: E501
        :rtype: float
        """
        return self._candidates_to_be_video_evaluated

    @candidates_to_be_video_evaluated.setter
    def candidates_to_be_video_evaluated(self, candidates_to_be_video_evaluated):
        """Sets the candidates_to_be_video_evaluated of this JobDetails.

        Number of candidates whose video evaluation is done.  # noqa: E501

        :param candidates_to_be_video_evaluated: The candidates_to_be_video_evaluated of this JobDetails.  # noqa: E501
        :type: float
        """

        self._candidates_to_be_video_evaluated = candidates_to_be_video_evaluated

    @property
    def review_criteria_refinement_disabled(self):
        """Gets the review_criteria_refinement_disabled of this JobDetails.  # noqa: E501

        Indicates if the review criteria refinement is disabled.  # noqa: E501

        :return: The review_criteria_refinement_disabled of this JobDetails.  # noqa: E501
        :rtype: bool
        """
        return self._review_criteria_refinement_disabled

    @review_criteria_refinement_disabled.setter
    def review_criteria_refinement_disabled(self, review_criteria_refinement_disabled):
        """Sets the review_criteria_refinement_disabled of this JobDetails.

        Indicates if the review criteria refinement is disabled.  # noqa: E501

        :param review_criteria_refinement_disabled: The review_criteria_refinement_disabled of this JobDetails.  # noqa: E501
        :type: bool
        """

        self._review_criteria_refinement_disabled = review_criteria_refinement_disabled

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(JobDetails, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, JobDetails):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
